# Next.js App Router Hooks

A collection of utility hooks for Next.js App Router.

## Installation

```bash
npm install nextjs-app-hooks
# or
yarn add nextjs-app-hooks
# or
pnpm add nextjs-app-hooks
Hooks
useIsServer
A hook to detect if the code is running on the server or client.
tsxCopy'use client';

import { useIsServer } from 'nextjs-app-hooks';

export default function MyComponent() {
  const isServer = useIsServer();

  return (
    <div>
      {isServer ? 'Rendering on server' : 'Rendering on client'}
    </div>
  );
}
Why is this useful?
In Next.js App Router, components can be either Server Components or Client Components. Sometimes you need to know if your client component is currently rendering on the server (during SSR) or on the client (after hydration). This hook helps you detect that.
Use cases:

Conditionally rendering content that depends on browser APIs
Avoiding hydration mismatches
Implementing progressive enhancement
Handling browser-only libraries

Important Notes

This hook must be used within a Client Component (with 'use client' directive)
It cannot be used in Server Components

License
MIT
```
