"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var index_exports = {};
__export(index_exports, {
  breakpoints: () => breakpoints,
  useBattery: () => useBattery,
  useClickOutside: () => useClickOutside,
  useClipboard: () => useClipboard,
  useCookie: () => useCookie,
  useCookies: () => useCookies,
  useDarkMode: () => useDarkMode,
  useDebounce: () => useDebounce,
  useFetch: () => useFetch,
  useGeolocation: () => useGeolocation,
  useHasRendered: () => useHasRendered,
  useHover: () => useHover,
  useIdle: () => useIdle,
  useIntersectionObserver: () => useIntersectionObserver,
  useIsBrowser: () => useIsBrowser,
  useIsServer: () => useIsServer,
  useLocalStorage: () => useLocalStorage,
  useLockBodyScroll: () => useLockBodyScroll,
  useLongPress: () => useLongPress,
  useMediaQueries: () => useMediaQueries,
  useMediaQuery: () => useMediaQuery,
  useMouse: () => useMouse,
  useMouseHover: () => useMouseHover,
  useNetwork: () => useNetwork,
  useOrientation: () => useOrientation,
  usePreferredLanguage: () => usePreferredLanguage,
  usePrefersReducedMotion: () => usePrefersReducedMotion,
  useResponsive: () => useResponsive,
  useSessionStorage: () => useSessionStorage,
  useSessionStorageObject: () => useSessionStorageObject
});
module.exports = __toCommonJS(index_exports);

// src/hooks/useIsBrowser.ts
var import_react = require("react");
function useIsBrowser() {
  const [isBrowser, setIsBrowser] = (0, import_react.useState)(false);
  (0, import_react.useEffect)(() => {
    setIsBrowser(true);
  }, []);
  return isBrowser;
}

// src/hooks/useIsServer.ts
var import_react2 = require("react");
function useIsServer() {
  const [isServer, setIsServer] = (0, import_react2.useState)(true);
  (0, import_react2.useEffect)(() => {
    setIsServer(false);
  }, []);
  return isServer;
}

// src/hooks/useBattery.ts
var import_react3 = require("react");
function useBattery() {
  const [state, setState] = (0, import_react3.useState)({
    isSupported: false,
    isLoading: true,
    error: null,
    battery: null
  });
  (0, import_react3.useEffect)(() => {
    if (!navigator || !("getBattery" in navigator)) {
      setState({
        isSupported: false,
        isLoading: false,
        error: null,
        battery: null
      });
      return;
    }
    let batteryManager = null;
    let isComponentMounted = true;
    const updateBatteryState = (manager) => {
      if (!isComponentMounted) return;
      if (!manager) {
        setState((prev) => ({
          ...prev,
          isLoading: false,
          error: new Error("Could not access battery information"),
          battery: null
        }));
        return;
      }
      setState({
        isSupported: true,
        isLoading: false,
        error: null,
        battery: {
          charging: manager.charging,
          chargingTime: manager.chargingTime,
          dischargingTime: manager.dischargingTime,
          level: manager.level,
          connected: manager.charging || manager.level === 1 && manager.chargingTime === 0
        }
      });
    };
    const setupBatteryListeners = (manager) => {
      if (!manager) return;
      manager.addEventListener(
        "chargingchange",
        () => updateBatteryState(manager)
      );
      manager.addEventListener(
        "chargingtimechange",
        () => updateBatteryState(manager)
      );
      manager.addEventListener(
        "dischargingtimechange",
        () => updateBatteryState(manager)
      );
      manager.addEventListener(
        "levelchange",
        () => updateBatteryState(manager)
      );
      batteryManager = manager;
    };
    const getBatteryInfo = async () => {
      try {
        const manager = await navigator.getBattery();
        if (isComponentMounted) {
          updateBatteryState(manager);
          setupBatteryListeners(manager);
        }
      } catch (error) {
        if (isComponentMounted) {
          setState({
            isSupported: true,
            // API exists but there was an error
            isLoading: false,
            error: error instanceof Error ? error : new Error("Unknown battery error"),
            battery: null
          });
        }
      }
    };
    getBatteryInfo();
    return () => {
      isComponentMounted = false;
      if (batteryManager) {
        batteryManager.removeEventListener(
          "chargingchange",
          updateBatteryState
        );
        batteryManager.removeEventListener(
          "chargingtimechange",
          updateBatteryState
        );
        batteryManager.removeEventListener(
          "dischargingtimechange",
          updateBatteryState
        );
        batteryManager.removeEventListener("levelchange", updateBatteryState);
      }
    };
  }, []);
  return state;
}

// src/hooks/useClickOutside.ts
var import_react4 = require("react");
var import_react5 = require("react");
function useClickOutside(onClickOutside, options = {}) {
  const {
    enabled = true,
    ignoreRefs = [],
    mouseEvents = ["mousedown"],
    listenForTouchEvents = true,
    ignoreScrollbar = true
  } = options;
  const ref = (0, import_react4.useRef)(null);
  const handleClickOutside = (0, import_react4.useCallback)(
    (event) => {
      if (!enabled) return;
      const target = event.target;
      if (ignoreScrollbar && event instanceof MouseEvent) {
        if (event.clientX >= document.documentElement.clientWidth) {
          return;
        }
      }
      if (ref.current && ref.current.contains(target)) {
        return;
      }
      for (const ignoreRef of ignoreRefs) {
        if (ignoreRef.current && ignoreRef.current.contains(target)) {
          return;
        }
      }
      onClickOutside(event);
    },
    [enabled, ignoreRefs, ignoreScrollbar, onClickOutside]
  );
  (0, import_react4.useEffect)(() => {
    if (!enabled) return;
    mouseEvents.forEach((mouseEvent) => {
      document.addEventListener(
        mouseEvent,
        handleClickOutside
      );
    });
    if (listenForTouchEvents) {
      document.addEventListener(
        "touchstart",
        handleClickOutside
      );
    }
    return () => {
      mouseEvents.forEach((mouseEvent) => {
        document.removeEventListener(
          mouseEvent,
          handleClickOutside
        );
      });
      if (listenForTouchEvents) {
        document.removeEventListener(
          "touchstart",
          handleClickOutside
        );
      }
    };
  }, [enabled, mouseEvents, listenForTouchEvents, handleClickOutside]);
  return ref;
}

// src/hooks/useClipboard.ts
var import_react6 = require("react");
function useClipboard(options = {}) {
  const {
    resetDelay = 2e3,
    autoReset = true,
    initialValue = "",
    modernOnly = false,
    onCopySuccess,
    onCopyError
  } = options;
  const isBrowser = useIsBrowser();
  const [value, setValue] = (0, import_react6.useState)(initialValue);
  const [status, setStatus] = (0, import_react6.useState)("idle");
  const [error, setError] = (0, import_react6.useState)(null);
  const isModernSupported = isBrowser && typeof navigator !== "undefined" && navigator.clipboard && typeof navigator.clipboard.writeText === "function";
  const isLegacySupported = isBrowser && typeof document !== "undefined" && typeof document.execCommand === "function";
  const isSupported = isModernSupported || !modernOnly && isLegacySupported;
  (0, import_react6.useEffect)(() => {
    if (status !== "idle" && autoReset) {
      const timeoutId = setTimeout(() => {
        setStatus("idle");
      }, resetDelay);
      return () => clearTimeout(timeoutId);
    }
  }, [status, resetDelay, autoReset]);
  const copyWithLegacyMethod = (0, import_react6.useCallback)((text) => {
    try {
      const textarea = document.createElement("textarea");
      textarea.value = text;
      textarea.style.position = "absolute";
      textarea.style.opacity = "0";
      textarea.style.pointerEvents = "none";
      textarea.style.zIndex = "-1";
      document.body.appendChild(textarea);
      textarea.focus();
      textarea.select();
      const success = document.execCommand("copy");
      document.body.removeChild(textarea);
      return success;
    } catch (err) {
      return false;
    }
  }, []);
  const copyToClipboard = (0, import_react6.useCallback)(
    async (text) => {
      if (!isBrowser) {
        setStatus("error");
        const browserError = new Error(
          "Cannot copy to clipboard on the server"
        );
        setError(browserError);
        onCopyError?.(browserError);
        return false;
      }
      const valueToCopy = text !== void 0 ? text : value;
      setValue(valueToCopy);
      try {
        let success = false;
        if (isModernSupported) {
          await navigator.clipboard.writeText(valueToCopy);
          success = true;
        } else if (!modernOnly && isLegacySupported) {
          success = copyWithLegacyMethod(valueToCopy);
        } else {
          throw new Error("Clipboard API not supported in this environment");
        }
        if (success) {
          setStatus("copied");
          setError(null);
          onCopySuccess?.(valueToCopy);
          return true;
        } else {
          throw new Error("Failed to copy to clipboard");
        }
      } catch (err) {
        setStatus("error");
        const copyError = err instanceof Error ? err : new Error(String(err));
        setError(copyError);
        onCopyError?.(copyError);
        return false;
      }
    },
    [
      isBrowser,
      value,
      isModernSupported,
      modernOnly,
      isLegacySupported,
      copyWithLegacyMethod,
      onCopySuccess,
      onCopyError
    ]
  );
  const reset = (0, import_react6.useCallback)(() => {
    setStatus("idle");
    setError(null);
  }, []);
  return {
    copyToClipboard,
    value,
    status,
    isSuccess: status === "copied",
    isError: status === "error",
    reset,
    error,
    isSupported
  };
}

// src/hooks/useDebounce.ts
var import_react7 = require("react");
function useDebounce(fn, options = {}) {
  const {
    delay = 500,
    leading = false,
    maxWait,
    trackPending = false
  } = options;
  const timeoutRef = (0, import_react7.useRef)(null);
  const lastCalledRef = (0, import_react7.useRef)(0);
  const maxTimeoutRef = (0, import_react7.useRef)(null);
  const lastArgsRef = (0, import_react7.useRef)(null);
  const lastResultRef = (0, import_react7.useRef)(void 0);
  const [isPending, setIsPending] = (0, import_react7.useState)(false);
  const cancel = (0, import_react7.useCallback)(() => {
    if (timeoutRef.current) {
      clearTimeout(timeoutRef.current);
      timeoutRef.current = null;
    }
    if (maxTimeoutRef.current) {
      clearTimeout(maxTimeoutRef.current);
      maxTimeoutRef.current = null;
    }
    if (trackPending && isPending) {
      setIsPending(false);
    }
  }, [isPending, trackPending]);
  const executeFunction = (0, import_react7.useCallback)(
    (...args) => {
      lastCalledRef.current = Date.now();
      lastArgsRef.current = null;
      if (trackPending) {
        setIsPending(false);
      }
      try {
        const result = fn(...args);
        lastResultRef.current = result;
        return result;
      } catch (error) {
        lastResultRef.current = void 0;
        throw error;
      }
    },
    [fn, trackPending]
  );
  const flush = (0, import_react7.useCallback)(() => {
    if (timeoutRef.current || maxTimeoutRef.current) {
      if (lastArgsRef.current) {
        const result = executeFunction(...lastArgsRef.current);
        lastArgsRef.current = null;
        return result;
      }
    }
    return lastResultRef.current;
  }, [executeFunction]);
  (0, import_react7.useEffect)(() => {
    return () => cancel();
  }, [cancel]);
  const debounced = (0, import_react7.useCallback)(
    (...args) => {
      lastArgsRef.current = args;
      const now = Date.now();
      const timeSinceLastCall = now - lastCalledRef.current;
      if (trackPending && !isPending) {
        setIsPending(true);
      }
      if (timeoutRef.current) {
        clearTimeout(timeoutRef.current);
      }
      if (leading && (lastCalledRef.current === 0 || timeSinceLastCall >= delay)) {
        executeFunction(...args);
      } else {
        timeoutRef.current = setTimeout(() => {
          if (maxTimeoutRef.current) {
            clearTimeout(maxTimeoutRef.current);
            maxTimeoutRef.current = null;
          }
          executeFunction(...args);
        }, delay);
        if (maxWait && !maxTimeoutRef.current && timeSinceLastCall >= maxWait) {
          maxTimeoutRef.current = setTimeout(() => {
            if (timeoutRef.current) {
              clearTimeout(timeoutRef.current);
              timeoutRef.current = null;
            }
            executeFunction(...args);
          }, maxWait - timeSinceLastCall);
        }
      }
    },
    [delay, executeFunction, isPending, leading, maxWait, trackPending]
  );
  return [debounced, cancel, isPending, flush];
}

// src/hooks/useGeolocation.ts
var import_react8 = require("react");
function useGeolocation(options = {}) {
  const {
    enableHighAccuracy = false,
    timeout = 1e4,
    maximumAge = 0,
    watchPosition: shouldWatch = false,
    autoRequest = true,
    onSuccess,
    onError,
    onPermissionChange
  } = options;
  const isBrowser = useIsBrowser();
  const [position, setPosition] = (0, import_react8.useState)(null);
  const [error, setError] = (0, import_react8.useState)(
    null
  );
  const [isLoading, setIsLoading] = (0, import_react8.useState)(false);
  const [isWatching, setIsWatching] = (0, import_react8.useState)(false);
  const [permissionState, setPermissionState] = (0, import_react8.useState)("unknown");
  const watchIdRef = (0, import_react8.useRef)(null);
  const isSupported = isBrowser && typeof navigator !== "undefined" && "geolocation" in navigator;
  const formatPosition = (0, import_react8.useCallback)(
    (position2) => {
      return {
        latitude: position2.latitude,
        longitude: position2.longitude,
        accuracy: position2.accuracy,
        altitude: position2.altitude,
        altitudeAccuracy: position2.altitudeAccuracy,
        heading: position2.heading,
        speed: position2.speed,
        timestamp: position2.timestamp
      };
    },
    []
  );
  const handlePositionSuccess = (0, import_react8.useCallback)(
    (rawPosition) => {
      const formattedPosition = formatPosition(rawPosition);
      setPosition(formattedPosition);
      setError(null);
      setIsLoading(false);
      onSuccess?.(formattedPosition);
    },
    [formatPosition, onSuccess]
  );
  const handlePositionError = (0, import_react8.useCallback)(
    (positionError) => {
      setError(positionError);
      setIsLoading(false);
      onError?.(positionError);
      if (positionError instanceof GeolocationPositionError && positionError.code === 1 /* PERMISSION_DENIED */) {
        setPermissionState("denied");
        onPermissionChange?.("denied");
      }
    },
    [onError, onPermissionChange]
  );
  const getPosition = (0, import_react8.useCallback)(() => {
    return new Promise((resolve, reject) => {
      if (!isSupported) {
        const error2 = new Error(
          "Geolocation is not supported by this browser."
        );
        setError(error2);
        reject(error2);
        return;
      }
      setIsLoading(true);
      setError(null);
      navigator.geolocation.getCurrentPosition(
        (rawPosition) => {
          const formattedPosition = {
            latitude: rawPosition.coords.latitude,
            longitude: rawPosition.coords.longitude,
            accuracy: rawPosition.coords.accuracy,
            altitude: rawPosition.coords.altitude,
            altitudeAccuracy: rawPosition.coords.altitudeAccuracy,
            heading: rawPosition.coords.heading,
            speed: rawPosition.coords.speed,
            timestamp: rawPosition.timestamp
          };
          handlePositionSuccess(formattedPosition);
          resolve(formattedPosition);
        },
        (positionError) => {
          handlePositionError(positionError);
          reject(positionError);
        },
        {
          enableHighAccuracy,
          timeout,
          maximumAge
        }
      );
    });
  }, [
    isSupported,
    enableHighAccuracy,
    timeout,
    maximumAge,
    handlePositionSuccess,
    handlePositionError
  ]);
  const watchPosition = (0, import_react8.useCallback)(() => {
    if (!isSupported) {
      const error2 = new Error("Geolocation is not supported by this browser.");
      setError(error2);
      return;
    }
    if (watchIdRef.current !== null) {
      navigator.geolocation.clearWatch(watchIdRef.current);
    }
    setIsLoading(true);
    setError(null);
    setIsWatching(true);
    watchIdRef.current = navigator.geolocation.watchPosition(
      (rawPosition) => {
        const formattedPosition = {
          latitude: rawPosition.coords.latitude,
          longitude: rawPosition.coords.longitude,
          accuracy: rawPosition.coords.accuracy,
          altitude: rawPosition.coords.altitude,
          altitudeAccuracy: rawPosition.coords.altitudeAccuracy,
          heading: rawPosition.coords.heading,
          speed: rawPosition.coords.speed,
          timestamp: rawPosition.timestamp
        };
        handlePositionSuccess(formattedPosition);
      },
      handlePositionError,
      {
        enableHighAccuracy,
        timeout,
        maximumAge
      }
    );
  }, [
    isSupported,
    enableHighAccuracy,
    timeout,
    maximumAge,
    handlePositionSuccess,
    handlePositionError
  ]);
  const stopWatching = (0, import_react8.useCallback)(() => {
    if (!isSupported || watchIdRef.current === null) return;
    navigator.geolocation.clearWatch(watchIdRef.current);
    watchIdRef.current = null;
    setIsWatching(false);
  }, [isSupported]);
  const checkPermissionState = (0, import_react8.useCallback)(async () => {
    if (!isBrowser) return "unknown";
    if (navigator.permissions && navigator.permissions.query) {
      try {
        const permissionStatus = await navigator.permissions.query({
          name: "geolocation"
        });
        const state = permissionStatus.state;
        setPermissionState(state);
        onPermissionChange?.(state);
        permissionStatus.addEventListener("change", () => {
          const newState = permissionStatus.state;
          setPermissionState(newState);
          onPermissionChange?.(newState);
        });
        return state;
      } catch (err) {
        console.warn("Permissions API error:", err);
      }
    }
    if (position) {
      setPermissionState("granted");
      return "granted";
    } else if (error instanceof GeolocationPositionError && error.code === 1 /* PERMISSION_DENIED */) {
      setPermissionState("denied");
      return "denied";
    }
    return "prompt";
  }, [isBrowser, position, error, onPermissionChange]);
  (0, import_react8.useEffect)(() => {
    if (isSupported) {
      checkPermissionState();
    }
  }, [isSupported, checkPermissionState]);
  (0, import_react8.useEffect)(() => {
    if (!isSupported || !autoRequest) return;
    if (shouldWatch) {
      watchPosition();
    } else {
      getPosition().catch(() => {
      });
    }
    return () => {
      if (watchIdRef.current !== null) {
        navigator.geolocation.clearWatch(watchIdRef.current);
        watchIdRef.current = null;
        setIsWatching(false);
      }
    };
  }, [isSupported, autoRequest, shouldWatch, watchPosition, getPosition]);
  return {
    position,
    error,
    isLoading,
    isWatching,
    permissionState,
    getPosition,
    watchPosition,
    stopWatching,
    isSupported
  };
}

// src/hooks/useHover.ts
var import_react9 = require("react");
function useHover(options = {}) {
  const {
    enterDelay = 0,
    leaveDelay = 0,
    enabled: initialEnabled = true,
    supportTouch = false,
    onHoverStart,
    onHoverEnd,
    onEnabledChange
  } = options;
  const isBrowser = useIsBrowser();
  const [isHovered, setIsHovered] = (0, import_react9.useState)(false);
  const [isEnabled, setIsEnabled] = (0, import_react9.useState)(initialEnabled);
  const hoverRef = (0, import_react9.useRef)(null);
  const enterTimeoutRef = (0, import_react9.useRef)(null);
  const leaveTimeoutRef = (0, import_react9.useRef)(null);
  const isTouchDevice = (0, import_react9.useRef)(false);
  const clearTimeouts = (0, import_react9.useCallback)(() => {
    if (enterTimeoutRef.current) {
      clearTimeout(enterTimeoutRef.current);
      enterTimeoutRef.current = null;
    }
    if (leaveTimeoutRef.current) {
      clearTimeout(leaveTimeoutRef.current);
      leaveTimeoutRef.current = null;
    }
  }, []);
  const handleEnter = (0, import_react9.useCallback)(
    (event) => {
      if (event.type.startsWith("mouse") && isTouchDevice.current) {
        return;
      }
      if (event.type.startsWith("touch")) {
        isTouchDevice.current = true;
      }
      if (leaveTimeoutRef.current) {
        clearTimeout(leaveTimeoutRef.current);
        leaveTimeoutRef.current = null;
      }
      if (enterDelay > 0) {
        enterTimeoutRef.current = setTimeout(() => {
          setIsHovered(true);
          onHoverStart?.(event);
        }, enterDelay);
      } else {
        setIsHovered(true);
        onHoverStart?.(event);
      }
    },
    [enterDelay, onHoverStart]
  );
  const handleLeave = (0, import_react9.useCallback)(
    (event) => {
      if (event.type.startsWith("mouse") && isTouchDevice.current) {
        return;
      }
      if (enterTimeoutRef.current) {
        clearTimeout(enterTimeoutRef.current);
        enterTimeoutRef.current = null;
      }
      if (leaveDelay > 0) {
        leaveTimeoutRef.current = setTimeout(() => {
          setIsHovered(false);
          onHoverEnd?.(event);
        }, leaveDelay);
      } else {
        setIsHovered(false);
        onHoverEnd?.(event);
      }
    },
    [leaveDelay, onHoverEnd]
  );
  const enable = (0, import_react9.useCallback)(() => {
    if (!isEnabled) {
      setIsEnabled(true);
      onEnabledChange?.(true);
    }
  }, [isEnabled, onEnabledChange]);
  const disable = (0, import_react9.useCallback)(() => {
    if (isEnabled) {
      setIsEnabled(false);
      setIsHovered(false);
      clearTimeouts();
      onEnabledChange?.(false);
    }
  }, [isEnabled, clearTimeouts, onEnabledChange]);
  (0, import_react9.useEffect)(() => {
    const element = hoverRef.current;
    if (!isBrowser || !element || !isEnabled) {
      return;
    }
    if (typeof window !== "undefined") {
      isTouchDevice.current = "ontouchstart" in window || navigator.maxTouchPoints > 0 || navigator.msMaxTouchPoints > 0;
    }
    element.addEventListener("mouseenter", handleEnter);
    element.addEventListener("mouseleave", handleLeave);
    if (supportTouch) {
      element.addEventListener("touchstart", handleEnter, {
        passive: true
      });
      element.addEventListener("touchend", handleLeave, {
        passive: true
      });
      const handleTouchMove = (event) => {
        const touch = event.touches[0];
        if (touch && element) {
          const rect = element.getBoundingClientRect();
          if (touch.clientX < rect.left || touch.clientX > rect.right || touch.clientY < rect.top || touch.clientY > rect.bottom) {
            handleLeave(event);
          }
        }
      };
      document.addEventListener("touchmove", handleTouchMove, {
        passive: true
      });
      return () => {
        element.removeEventListener("mouseenter", handleEnter);
        element.removeEventListener("mouseleave", handleLeave);
        element.removeEventListener("touchstart", handleEnter);
        element.removeEventListener("touchend", handleLeave);
        document.removeEventListener(
          "touchmove",
          handleTouchMove
        );
        clearTimeouts();
      };
    }
    return () => {
      element.removeEventListener("mouseenter", handleEnter);
      element.removeEventListener("mouseleave", handleLeave);
      clearTimeouts();
    };
  }, [
    isBrowser,
    isEnabled,
    supportTouch,
    handleEnter,
    handleLeave,
    clearTimeouts
  ]);
  (0, import_react9.useEffect)(() => {
    if (initialEnabled !== isEnabled) {
      setIsEnabled(initialEnabled);
    }
  }, [initialEnabled, isEnabled]);
  (0, import_react9.useEffect)(() => {
    return () => {
      clearTimeouts();
    };
  }, [clearTimeouts]);
  return {
    hoverRef,
    isHovered,
    enable,
    disable,
    isEnabled
  };
}

// src/hooks/useIdle.ts
var import_react10 = require("react");
function useIdle(options = {}) {
  const {
    idleTime = 6e4,
    // Default 1 minute
    initialState = false,
    events = [
      "mousemove",
      "mousedown",
      "resize",
      "keydown",
      "touchstart",
      "wheel"
    ],
    minimumMovement = 10,
    trackInBackground = true,
    onIdle,
    onActive,
    enabled: initialEnabled = true,
    idleOnVisibilityHidden = false,
    syncWithStorage = false,
    storageKey = "user-idle-state",
    emitEvents = false,
    eventName = "user-idle-state-change",
    pollingInterval = 1e3
  } = options;
  const isBrowser = useIsBrowser();
  const [isIdle, setIsIdle] = (0, import_react10.useState)(initialState);
  const [isEnabled, setIsEnabled] = (0, import_react10.useState)(initialEnabled);
  const [idleTimeTracked, setIdleTimeTracked] = (0, import_react10.useState)(0);
  const [remainingTimeValue, setRemainingTimeValue] = (0, import_react10.useState)(idleTime);
  const lastActiveRef = (0, import_react10.useRef)(Date.now());
  const timerRef = (0, import_react10.useRef)(null);
  const pollingIntervalRef = (0, import_react10.useRef)(null);
  const lastMousePositionRef = (0, import_react10.useRef)({ x: 0, y: 0 });
  const lastEventHandlerRef = (0, import_react10.useRef)(() => {
  });
  const initTimer = (0, import_react10.useCallback)(() => {
    if (!isBrowser || !isEnabled) return;
    if (timerRef.current) {
      clearTimeout(timerRef.current);
    }
    timerRef.current = setTimeout(() => {
      if (!document.hidden || trackInBackground) {
        setIsIdle(true);
        onIdle?.();
        if (syncWithStorage) {
          try {
            localStorage.setItem(
              storageKey,
              JSON.stringify({
                isIdle: true,
                timestamp: Date.now()
              })
            );
          } catch (e) {
            console.warn("Failed to sync idle state to localStorage", e);
          }
        }
        if (emitEvents && typeof window !== "undefined") {
          const idleEvent = new CustomEvent(eventName, {
            detail: {
              isIdle: true,
              idleTime: Date.now() - lastActiveRef.current,
              timestamp: Date.now()
            }
          });
          window.dispatchEvent(idleEvent);
        }
      }
    }, idleTime);
    return () => {
      if (timerRef.current) {
        clearTimeout(timerRef.current);
      }
    };
  }, [
    isBrowser,
    isEnabled,
    idleTime,
    trackInBackground,
    onIdle,
    syncWithStorage,
    storageKey,
    emitEvents,
    eventName
  ]);
  const startPolling = (0, import_react10.useCallback)(() => {
    if (!isBrowser || !isEnabled) return;
    if (pollingIntervalRef.current) {
      clearInterval(pollingIntervalRef.current);
    }
    pollingIntervalRef.current = setInterval(() => {
      const now = Date.now();
      const elapsed = now - lastActiveRef.current;
      const remaining = Math.max(0, idleTime - elapsed);
      setIdleTimeTracked(elapsed);
      setRemainingTimeValue(remaining);
    }, pollingInterval);
    return () => {
      if (pollingIntervalRef.current) {
        clearInterval(pollingIntervalRef.current);
        pollingIntervalRef.current = null;
      }
    };
  }, [isBrowser, isEnabled, idleTime, pollingInterval]);
  const handleActivity = (0, import_react10.useCallback)(
    (event) => {
      if (!isEnabled) return;
      let shouldReset = true;
      if (event && event.type === "mousemove" && minimumMovement > 0) {
        const mouseEvent = event;
        const { x, y } = lastMousePositionRef.current;
        const deltaX = Math.abs(mouseEvent.clientX - x);
        const deltaY = Math.abs(mouseEvent.clientY - y);
        const distance = Math.sqrt(deltaX * deltaX + deltaY * deltaY);
        shouldReset = distance >= minimumMovement;
        lastMousePositionRef.current = {
          x: mouseEvent.clientX,
          y: mouseEvent.clientY
        };
      }
      if (shouldReset) {
        const wasIdle = isIdle;
        const now = Date.now();
        lastActiveRef.current = now;
        if (wasIdle) {
          setIsIdle(false);
          onActive?.();
          if (syncWithStorage) {
            try {
              localStorage.setItem(
                storageKey,
                JSON.stringify({
                  isIdle: false,
                  timestamp: now
                })
              );
            } catch (e) {
              console.warn("Failed to sync idle state to localStorage", e);
            }
          }
          if (emitEvents && typeof window !== "undefined") {
            const activeEvent = new CustomEvent(eventName, {
              detail: {
                isIdle: false,
                idleTime: 0,
                timestamp: now
              }
            });
            window.dispatchEvent(activeEvent);
          }
        }
        initTimer();
      }
    },
    [
      isEnabled,
      isIdle,
      minimumMovement,
      onActive,
      initTimer,
      syncWithStorage,
      storageKey,
      emitEvents,
      eventName
    ]
  );
  const handleVisibilityChange = (0, import_react10.useCallback)(() => {
    if (!isEnabled) return;
    if (document.hidden && idleOnVisibilityHidden) {
      setIsIdle(true);
      onIdle?.();
      if (syncWithStorage) {
        try {
          localStorage.setItem(
            storageKey,
            JSON.stringify({
              isIdle: true,
              timestamp: Date.now()
            })
          );
        } catch (e) {
          console.warn("Failed to sync idle state to localStorage", e);
        }
      }
    } else if (!document.hidden && isIdle) {
      handleActivity();
    }
  }, [
    isEnabled,
    idleOnVisibilityHidden,
    isIdle,
    onIdle,
    syncWithStorage,
    storageKey,
    handleActivity
  ]);
  const handleStorageChange = (0, import_react10.useCallback)(
    (e) => {
      if (!isEnabled || !syncWithStorage || e.key !== storageKey) return;
      try {
        const data = e.newValue ? JSON.parse(e.newValue) : null;
        if (data && typeof data.isIdle === "boolean") {
          setIsIdle(data.isIdle);
          if (data.isIdle) {
            onIdle?.();
          } else {
            lastActiveRef.current = data.timestamp || Date.now();
            onActive?.();
            initTimer();
          }
        }
      } catch (err) {
        console.warn("Failed to parse idle state from localStorage", err);
      }
    },
    [isEnabled, syncWithStorage, storageKey, onIdle, onActive, initTimer]
  );
  const setIdleManually = (0, import_react10.useCallback)(() => {
    setIsIdle(true);
    onIdle?.();
    if (syncWithStorage) {
      try {
        localStorage.setItem(
          storageKey,
          JSON.stringify({
            isIdle: true,
            timestamp: Date.now()
          })
        );
      } catch (e) {
        console.warn("Failed to sync idle state to localStorage", e);
      }
    }
    if (emitEvents && typeof window !== "undefined") {
      const idleEvent = new CustomEvent(eventName, {
        detail: {
          isIdle: true,
          idleTime: Date.now() - lastActiveRef.current,
          timestamp: Date.now()
        }
      });
      window.dispatchEvent(idleEvent);
    }
  }, [onIdle, syncWithStorage, storageKey, emitEvents, eventName]);
  const setActiveManually = (0, import_react10.useCallback)(() => {
    lastActiveRef.current = Date.now();
    setIsIdle(false);
    onActive?.();
    initTimer();
    if (syncWithStorage) {
      try {
        localStorage.setItem(
          storageKey,
          JSON.stringify({
            isIdle: false,
            timestamp: Date.now()
          })
        );
      } catch (e) {
        console.warn("Failed to sync idle state to localStorage", e);
      }
    }
    if (emitEvents && typeof window !== "undefined") {
      const activeEvent = new CustomEvent(eventName, {
        detail: {
          isIdle: false,
          idleTime: 0,
          timestamp: Date.now()
        }
      });
      window.dispatchEvent(activeEvent);
    }
  }, [onActive, initTimer, syncWithStorage, storageKey, emitEvents, eventName]);
  const reset = (0, import_react10.useCallback)(() => {
    if (isIdle) {
      setActiveManually();
    } else {
      lastActiveRef.current = Date.now();
      initTimer();
    }
  }, [isIdle, setActiveManually, initTimer]);
  const enable = (0, import_react10.useCallback)(() => {
    if (!isEnabled) {
      setIsEnabled(true);
      lastActiveRef.current = Date.now();
      initTimer();
      startPolling();
    }
  }, [isEnabled, initTimer, startPolling]);
  const disable = (0, import_react10.useCallback)(() => {
    if (isEnabled) {
      setIsEnabled(false);
      if (timerRef.current) {
        clearTimeout(timerRef.current);
        timerRef.current = null;
      }
      if (pollingIntervalRef.current) {
        clearInterval(pollingIntervalRef.current);
        pollingIntervalRef.current = null;
      }
      setIsIdle(false);
    }
  }, [isEnabled]);
  (0, import_react10.useEffect)(() => {
    if (!isBrowser) return;
    if (syncWithStorage) {
      try {
        const storedState = localStorage.getItem(storageKey);
        if (storedState) {
          const { isIdle: storedIsIdle, timestamp } = JSON.parse(storedState);
          if (typeof storedIsIdle === "boolean") {
            setIsIdle(storedIsIdle);
            if (!storedIsIdle && timestamp) {
              lastActiveRef.current = timestamp;
            }
          }
        }
      } catch (e) {
        console.warn("Failed to load idle state from localStorage", e);
      }
    }
    lastEventHandlerRef.current = handleActivity;
    if (isEnabled) {
      lastActiveRef.current = Date.now();
      initTimer();
      startPolling();
    }
    return () => {
      if (timerRef.current) {
        clearTimeout(timerRef.current);
      }
      if (pollingIntervalRef.current) {
        clearInterval(pollingIntervalRef.current);
      }
    };
  }, [
    isBrowser,
    isEnabled,
    initTimer,
    startPolling,
    syncWithStorage,
    storageKey,
    handleActivity
  ]);
  (0, import_react10.useEffect)(() => {
    if (!isBrowser || !isEnabled) return;
    const eventHandler = (event) => {
      lastEventHandlerRef.current(event);
    };
    events.forEach((eventName2) => {
      if (eventName2 === "visibilitychange") {
        document.addEventListener(
          eventName2,
          handleVisibilityChange
        );
      } else {
        window.addEventListener(eventName2, eventHandler, {
          passive: true
        });
      }
    });
    if (syncWithStorage) {
      window.addEventListener("storage", handleStorageChange);
    }
    return () => {
      events.forEach((eventName2) => {
        if (eventName2 === "visibilitychange") {
          document.removeEventListener(
            eventName2,
            handleVisibilityChange
          );
        } else {
          window.removeEventListener(eventName2, eventHandler);
        }
      });
      if (syncWithStorage) {
        window.removeEventListener("storage", handleStorageChange);
      }
    };
  }, [
    isBrowser,
    isEnabled,
    events,
    handleVisibilityChange,
    syncWithStorage,
    handleStorageChange
  ]);
  (0, import_react10.useEffect)(() => {
    if (initialEnabled !== isEnabled) {
      if (initialEnabled) {
        enable();
      } else {
        disable();
      }
    }
  }, [initialEnabled, isEnabled, enable, disable]);
  const idlePercentage = Math.min(
    100,
    Math.floor(idleTimeTracked / idleTime * 100)
  );
  return {
    isIdle,
    idleTime: idleTimeTracked,
    remainingTime: remainingTimeValue,
    lastActive: lastActiveRef.current,
    idlePercentage,
    setIdle: setIdleManually,
    setActive: setActiveManually,
    reset,
    enable,
    disable,
    isEnabled
  };
}

// src/hooks/useIntersectionObserver.ts
var import_react11 = require("react");
function useIntersectionObserver(options = {}) {
  const {
    root = null,
    rootMargin = "0px",
    threshold = 0,
    onEnter,
    onExit,
    triggerOnce = false,
    skip = false,
    initialInView = false,
    delay = 0,
    trackVisibilityChanges = false,
    historySize = 10,
    useIsIntersecting = true
  } = options;
  const isBrowser = useIsBrowser();
  const [isInView, setIsInView] = (0, import_react11.useState)(initialInView);
  const [intersectionRatio, setIntersectionRatio] = (0, import_react11.useState)(0);
  const [entry, setEntry] = (0, import_react11.useState)(null);
  const [entryHistory, setEntryHistory] = (0, import_react11.useState)(
    []
  );
  const [isConnected, setIsConnected] = (0, import_react11.useState)(false);
  const [enteredAt, setEnteredAt] = (0, import_react11.useState)(null);
  const [exitedAt, setExitedAt] = (0, import_react11.useState)(null);
  const [inViewDuration, setInViewDuration] = (0, import_react11.useState)(0);
  const ref = (0, import_react11.useRef)(null);
  const observerRef = (0, import_react11.useRef)(null);
  const skipRef = (0, import_react11.useRef)(skip);
  const wasInViewRef = (0, import_react11.useRef)(initialInView);
  const timerId = (0, import_react11.useRef)(null);
  const durationTimerId = (0, import_react11.useRef)(null);
  const disconnect = (0, import_react11.useCallback)(() => {
    if (observerRef.current) {
      observerRef.current.disconnect();
      setIsConnected(false);
      if (durationTimerId.current !== null) {
        cancelAnimationFrame(durationTimerId.current);
        durationTimerId.current = null;
      }
    }
  }, []);
  const updateInViewDuration = (0, import_react11.useCallback)(() => {
    if (isInView && enteredAt !== null) {
      setInViewDuration(Date.now() - enteredAt);
      durationTimerId.current = requestAnimationFrame(updateInViewDuration);
    } else {
      setInViewDuration(0);
    }
  }, [isInView, enteredAt]);
  const handleIntersection = (0, import_react11.useCallback)(
    (entries) => {
      if (skipRef.current) return;
      const entry2 = entries[0];
      const inThreshold = useIsIntersecting ? entry2.isIntersecting : entry2.intersectionRatio > 0;
      setEntry(entry2);
      setIntersectionRatio(entry2.intersectionRatio);
      if (trackVisibilityChanges) {
        setEntryHistory((prevEntries) => {
          const newEntries = [entry2, ...prevEntries];
          return newEntries.slice(0, historySize);
        });
      }
      if (inThreshold && !wasInViewRef.current) {
        wasInViewRef.current = true;
        setIsInView(true);
        setEnteredAt(Date.now());
        if (durationTimerId.current === null) {
          durationTimerId.current = requestAnimationFrame(updateInViewDuration);
        }
        onEnter?.(entry2);
        if (triggerOnce) {
          disconnect();
        }
      }
      if (!inThreshold && wasInViewRef.current) {
        wasInViewRef.current = false;
        setIsInView(false);
        setExitedAt(Date.now());
        if (durationTimerId.current !== null) {
          cancelAnimationFrame(durationTimerId.current);
          durationTimerId.current = null;
          setInViewDuration(0);
        }
        onExit?.(entry2);
      }
    },
    [
      disconnect,
      onEnter,
      onExit,
      triggerOnce,
      trackVisibilityChanges,
      historySize,
      useIsIntersecting,
      updateInViewDuration
    ]
  );
  const observe = (0, import_react11.useCallback)(() => {
    if (!isBrowser || !ref.current || skipRef.current) return;
    observerRef.current = new IntersectionObserver(handleIntersection, {
      root,
      rootMargin,
      threshold
    });
    observerRef.current.observe(ref.current);
    setIsConnected(true);
    return () => disconnect();
  }, [isBrowser, root, rootMargin, threshold, handleIntersection, disconnect]);
  const reset = (0, import_react11.useCallback)(() => {
    wasInViewRef.current = initialInView;
    setIsInView(initialInView);
    setIntersectionRatio(0);
    setEntry(null);
    setEntryHistory([]);
    setEnteredAt(null);
    setExitedAt(null);
    setInViewDuration(0);
    if (durationTimerId.current !== null) {
      cancelAnimationFrame(durationTimerId.current);
      durationTimerId.current = null;
    }
    disconnect();
    observe();
  }, [initialInView, disconnect, observe]);
  (0, import_react11.useEffect)(() => {
    skipRef.current = skip;
    if (skip && observerRef.current) {
      disconnect();
    } else if (!skip && ref.current && !observerRef.current) {
      observe();
    }
  }, [skip, disconnect, observe]);
  (0, import_react11.useEffect)(() => {
    if (delay > 0) {
      timerId.current = setTimeout(observe, delay);
      return () => {
        if (timerId.current !== null) {
          clearTimeout(timerId.current);
        }
        disconnect();
      };
    } else {
      observe();
      return () => disconnect();
    }
  }, [delay, observe, disconnect]);
  return {
    ref,
    isInView,
    intersectionRatio,
    entry,
    entryHistory,
    reset,
    disconnect,
    observe,
    isConnected,
    enteredAt,
    exitedAt,
    inViewDuration
  };
}

// src/hooks/useHasRendered.ts
var import_react12 = require("react");
function useHasRendered() {
  const hasRenderedRef = (0, import_react12.useRef)(false);
  if (!hasRenderedRef.current) {
    hasRenderedRef.current = true;
    return false;
  }
  return true;
}

// src/hooks/useLockBodyScroll.ts
var import_react13 = require("react");
function useLockBodyScroll(initialLocked = false, options = {}) {
  const {
    disabled = false,
    targetElement = null,
    preserveScrollPosition = true,
    reserveScrollbarGap = true
  } = options;
  const isBrowser = useIsBrowser();
  const [isLocked, setIsLocked] = (0, import_react13.useState)(initialLocked);
  const [originalStyles, setOriginalStyles] = (0, import_react13.useState)(
    {}
  );
  const [scrollbarWidth, setScrollbarWidth] = (0, import_react13.useState)(0);
  const measureScrollbarWidth = (0, import_react13.useCallback)(() => {
    if (!isBrowser) return 0;
    const outer = document.createElement("div");
    outer.style.visibility = "hidden";
    outer.style.overflow = "scroll";
    document.body.appendChild(outer);
    const inner = document.createElement("div");
    outer.appendChild(inner);
    const width = outer.offsetWidth - inner.offsetWidth;
    outer.parentNode?.removeChild(outer);
    setScrollbarWidth(width);
    return width;
  }, [isBrowser]);
  const lock = (0, import_react13.useCallback)(() => {
    if (!isBrowser || disabled) return;
    const target = targetElement || document.body;
    const originalOverflow = target.style.overflow;
    const originalPaddingRight = target.style.paddingRight;
    const originalPosition = target.style.position;
    const originalTop = target.style.top;
    const originalScrollY = window.scrollY;
    setOriginalStyles({
      overflow: originalOverflow,
      paddingRight: originalPaddingRight,
      position: originalPosition,
      top: originalTop,
      scrollY: originalScrollY.toString()
    });
    const sbWidth = reserveScrollbarGap ? scrollbarWidth || measureScrollbarWidth() : 0;
    const paddingRight = parseInt(window.getComputedStyle(target).paddingRight, 10) || 0;
    target.style.overflow = "hidden";
    if (reserveScrollbarGap) {
      target.style.paddingRight = `${paddingRight + sbWidth}px`;
    }
    if (preserveScrollPosition) {
      target.style.position = "fixed";
      target.style.top = `-${originalScrollY}px`;
      target.style.width = "100%";
    }
    setIsLocked(true);
  }, [
    isBrowser,
    disabled,
    targetElement,
    preserveScrollPosition,
    reserveScrollbarGap,
    scrollbarWidth,
    measureScrollbarWidth
  ]);
  const unlock = (0, import_react13.useCallback)(() => {
    if (!isBrowser || disabled) return;
    const target = targetElement || document.body;
    target.style.overflow = originalStyles.overflow || "";
    target.style.paddingRight = originalStyles.paddingRight || "";
    target.style.position = originalStyles.position || "";
    target.style.top = originalStyles.top || "";
    if (preserveScrollPosition && originalStyles.scrollY) {
      window.scrollTo(0, parseInt(originalStyles.scrollY, 10));
    }
    setIsLocked(false);
  }, [
    isBrowser,
    disabled,
    targetElement,
    originalStyles,
    preserveScrollPosition
  ]);
  const toggle = (0, import_react13.useCallback)(() => {
    if (isLocked) {
      unlock();
    } else {
      lock();
    }
  }, [isLocked, lock, unlock]);
  (0, import_react13.useEffect)(() => {
    if (initialLocked && !disabled) {
      lock();
    }
    return () => {
      if (isLocked) {
        unlock();
      }
    };
  }, [initialLocked, disabled, lock, unlock, isLocked]);
  (0, import_react13.useEffect)(() => {
    if (isBrowser && reserveScrollbarGap && scrollbarWidth === 0) {
      measureScrollbarWidth();
    }
  }, [isBrowser, reserveScrollbarGap, scrollbarWidth, measureScrollbarWidth]);
  return {
    isLocked,
    lock,
    unlock,
    toggle
  };
}

// src/hooks/useLongPress.ts
var import_react14 = require("react");
function useLongPress(callback, options = {}) {
  const isBrowser = useIsBrowser();
  const {
    delay = 500,
    disabled = false,
    preventDefault = true,
    stopPropagation = false,
    detectMouse = true,
    moveTolerance = 10,
    vibrate = false,
    vibrationPattern = [100],
    continuousLongPress = false,
    continuousLongPressInterval = 100,
    onPressStart,
    onPressMove,
    onLongPress,
    onLongPressEnd,
    onPressCancel,
    onClick
  } = options;
  const [isPressed, setIsPressed] = (0, import_react14.useState)(false);
  const [isLongPressed, setIsLongPressed] = (0, import_react14.useState)(false);
  const [position, setPosition] = (0, import_react14.useState)(null);
  const [movement, setMovement] = (0, import_react14.useState)(null);
  const timerRef = (0, import_react14.useRef)(null);
  const continuousTimerRef = (0, import_react14.useRef)(null);
  const initialPositionRef = (0, import_react14.useRef)(null);
  const currentPositionRef = (0, import_react14.useRef)(null);
  const isLongPressedRef = (0, import_react14.useRef)(false);
  const clearTimers = (0, import_react14.useCallback)(() => {
    if (timerRef.current) {
      clearTimeout(timerRef.current);
      timerRef.current = null;
    }
    if (continuousTimerRef.current) {
      clearInterval(continuousTimerRef.current);
      continuousTimerRef.current = null;
    }
  }, []);
  const reset = (0, import_react14.useCallback)(() => {
    setIsPressed(false);
    setIsLongPressed(false);
    setPosition(null);
    setMovement(null);
    initialPositionRef.current = null;
    currentPositionRef.current = null;
    isLongPressedRef.current = false;
    clearTimers();
  }, [clearTimers]);
  const calculateMovement = (0, import_react14.useCallback)(
    (initial, current) => {
      const deltaX = current.x - initial.x;
      const deltaY = current.y - initial.y;
      const distance = Math.sqrt(deltaX * deltaX + deltaY * deltaY);
      let direction = null;
      if (distance > 5) {
        if (Math.abs(deltaX) > Math.abs(deltaY)) {
          direction = deltaX > 0 ? "right" : "left";
        } else {
          direction = deltaY > 0 ? "down" : "up";
        }
      }
      return { distance, deltaX, deltaY, direction };
    },
    []
  );
  const triggerVibration = (0, import_react14.useCallback)(() => {
    if (isBrowser && vibrate && "vibrate" in navigator) {
      try {
        navigator.vibrate(vibrationPattern);
      } catch (e) {
        console.error("Vibration API error:", e);
      }
    }
  }, [isBrowser, vibrate, vibrationPattern]);
  const startLongPressTimer = (0, import_react14.useCallback)(() => {
    if (disabled || !initialPositionRef.current) return;
    clearTimers();
    timerRef.current = setTimeout(() => {
      if (initialPositionRef.current && currentPositionRef.current) {
        const moveData = calculateMovement(
          initialPositionRef.current,
          currentPositionRef.current
        );
        setIsLongPressed(true);
        isLongPressedRef.current = true;
        setMovement(moveData);
        triggerVibration();
        if (callback) callback({});
        if (onLongPress) onLongPress(currentPositionRef.current, moveData);
        if (continuousLongPress) {
          continuousTimerRef.current = setInterval(() => {
            if (currentPositionRef.current) {
              const currentMoveData = calculateMovement(
                initialPositionRef.current,
                currentPositionRef.current
              );
              if (onLongPress)
                onLongPress(currentPositionRef.current, currentMoveData);
            }
          }, continuousLongPressInterval);
        }
      }
    }, delay);
  }, [
    disabled,
    delay,
    callback,
    onLongPress,
    calculateMovement,
    triggerVibration,
    continuousLongPress,
    continuousLongPressInterval
  ]);
  const triggerLongPress = (0, import_react14.useCallback)(() => {
    if (disabled) return;
    const position2 = currentPositionRef.current || { x: 0, y: 0 };
    setIsPressed(true);
    setIsLongPressed(true);
    isLongPressedRef.current = true;
    setPosition(position2);
    const moveData = movement || {
      distance: 0,
      deltaX: 0,
      deltaY: 0,
      direction: null
    };
    setMovement(moveData);
    triggerVibration();
    if (callback) callback({});
    if (onLongPress) onLongPress(position2, moveData);
  }, [disabled, callback, onLongPress, triggerVibration, movement]);
  const cancelLongPress = (0, import_react14.useCallback)(() => {
    if (isLongPressedRef.current && onPressCancel) {
      onPressCancel();
    }
    reset();
  }, [onPressCancel, reset]);
  const getEventPosition = (0, import_react14.useCallback)(
    (e) => {
      if ("touches" in e) {
        return {
          x: e.touches[0]?.clientX || 0,
          y: e.touches[0]?.clientY || 0
        };
      }
      return {
        x: e.clientX,
        y: e.clientY
      };
    },
    []
  );
  const handlePressStart = (0, import_react14.useCallback)(
    (e) => {
      if (disabled) return;
      if (preventDefault) e.preventDefault();
      if (stopPropagation) e.stopPropagation();
      const pos = getEventPosition(e);
      setIsPressed(true);
      setIsLongPressed(false);
      setPosition(pos);
      setMovement(null);
      isLongPressedRef.current = false;
      initialPositionRef.current = pos;
      currentPositionRef.current = pos;
      if (onPressStart) onPressStart(pos);
      startLongPressTimer();
    },
    [
      disabled,
      preventDefault,
      stopPropagation,
      getEventPosition,
      onPressStart,
      startLongPressTimer
    ]
  );
  const handlePressMove = (0, import_react14.useCallback)(
    (e) => {
      if (!isPressed || disabled) return;
      if (preventDefault) e.preventDefault();
      if (stopPropagation) e.stopPropagation();
      const currentPos = getEventPosition(e);
      currentPositionRef.current = currentPos;
      setPosition(currentPos);
      if (initialPositionRef.current) {
        const moveData = calculateMovement(
          initialPositionRef.current,
          currentPos
        );
        setMovement(moveData);
        if (moveData.distance > moveTolerance) {
          clearTimers();
          if (!isLongPressedRef.current) {
            if (onPressCancel) onPressCancel();
          }
        }
        if (onPressMove) onPressMove(moveData);
      }
    },
    [
      isPressed,
      disabled,
      preventDefault,
      stopPropagation,
      getEventPosition,
      calculateMovement,
      moveTolerance,
      onPressMove,
      onPressCancel,
      clearTimers
    ]
  );
  const handlePressEnd = (0, import_react14.useCallback)(
    (e) => {
      if (!isPressed) return;
      if (preventDefault) e.preventDefault();
      if (stopPropagation) e.stopPropagation();
      const wasLongPress = isLongPressedRef.current;
      const wasQuickClick = !wasLongPress;
      if (wasLongPress) {
        if (onLongPressEnd && currentPositionRef.current && initialPositionRef.current) {
          const finalMoveData = calculateMovement(
            initialPositionRef.current,
            currentPositionRef.current
          );
          onLongPressEnd(currentPositionRef.current, finalMoveData);
        }
      } else if (wasQuickClick && initialPositionRef.current && currentPositionRef.current) {
        const moveData = calculateMovement(
          initialPositionRef.current,
          currentPositionRef.current
        );
        if (moveData.distance <= moveTolerance) {
          if (onClick) onClick(e);
        }
      }
      reset();
    },
    [
      isPressed,
      preventDefault,
      stopPropagation,
      onLongPressEnd,
      onClick,
      calculateMovement,
      moveTolerance,
      reset
    ]
  );
  const handlePressCancel = (0, import_react14.useCallback)(() => {
    if (!isPressed) return;
    if (onPressCancel) onPressCancel();
    reset();
  }, [isPressed, onPressCancel, reset]);
  const handleContextMenu = (0, import_react14.useCallback)(
    (e) => {
      if (!disabled && isLongPressed) {
        e.preventDefault();
      }
    },
    [disabled, isLongPressed]
  );
  const handleClick = (0, import_react14.useCallback)((e) => {
    if (isLongPressedRef.current) {
      e.preventDefault();
      e.stopPropagation();
    }
  }, []);
  (0, import_react14.useEffect)(() => {
    return () => {
      clearTimers();
    };
  }, [clearTimers]);
  const handlers = {
    onMouseDown: detectMouse ? handlePressStart : () => {
    },
    onMouseMove: detectMouse ? handlePressMove : () => {
    },
    onMouseUp: detectMouse ? handlePressEnd : () => {
    },
    onMouseLeave: detectMouse ? handlePressCancel : () => {
    },
    onTouchStart: handlePressStart,
    onTouchMove: handlePressMove,
    onTouchEnd: handlePressEnd,
    onContextMenu: handleContextMenu,
    onClick: handleClick
  };
  return {
    isPressed,
    isLongPressed,
    handlers,
    position,
    movement,
    triggerLongPress,
    cancelLongPress,
    reset
  };
}

// src/hooks/useMediaQuery.ts
var import_react15 = require("react");
var breakpoints = {
  xs: 0,
  sm: 576,
  md: 768,
  lg: 992,
  xl: 1200,
  xxl: 1400
};
function useMediaQuery(features, options = {}) {
  const {
    defaultValue = false,
    disabled = false,
    onChange,
    initializeWithDefaultValue = false,
    useEm = false,
    baseFontSize = 16
  } = options;
  const isBrowser = useIsBrowser();
  const resolveBreakpointValue = (0, import_react15.useCallback)(
    (value) => {
      if (value === void 0) return void 0;
      return typeof value === "string" ? breakpoints[value] : value;
    },
    []
  );
  const pxToEm = (0, import_react15.useCallback)(
    (px) => {
      return useEm ? px / baseFontSize : px;
    },
    [useEm, baseFontSize]
  );
  const createMediaQueryString = (0, import_react15.useCallback)(
    (featureInput) => {
      if (typeof featureInput === "string") {
        return featureInput;
      }
      if (featureInput.custom) {
        return featureInput.custom;
      }
      const conditions = [];
      const minWidth = resolveBreakpointValue(featureInput.minWidth);
      const maxWidth = resolveBreakpointValue(featureInput.maxWidth);
      if (minWidth !== void 0) {
        const value = useEm ? `${pxToEm(minWidth)}em` : `${minWidth}px`;
        conditions.push(`(min-width: ${value})`);
      }
      if (maxWidth !== void 0) {
        const value = useEm ? `${pxToEm(maxWidth)}em` : `${maxWidth}px`;
        conditions.push(`(max-width: ${value})`);
      }
      if (featureInput.minHeight !== void 0) {
        const value = useEm ? `${pxToEm(featureInput.minHeight)}em` : `${featureInput.minHeight}px`;
        conditions.push(`(min-height: ${value})`);
      }
      if (featureInput.maxHeight !== void 0) {
        const value = useEm ? `${pxToEm(featureInput.maxHeight)}em` : `${featureInput.maxHeight}px`;
        conditions.push(`(max-height: ${value})`);
      }
      if (featureInput.orientation) {
        conditions.push(`(orientation: ${featureInput.orientation})`);
      }
      if (featureInput.prefersColorScheme) {
        conditions.push(
          `(prefers-color-scheme: ${featureInput.prefersColorScheme})`
        );
      }
      if (featureInput.prefersReducedMotion !== void 0) {
        conditions.push(
          `(prefers-reduced-motion: ${featureInput.prefersReducedMotion ? "reduce" : "no-preference"})`
        );
      }
      if (featureInput.displayMode) {
        conditions.push(`(display-mode: ${featureInput.displayMode})`);
      }
      return conditions.join(" and ");
    },
    [resolveBreakpointValue, pxToEm, useEm]
  );
  const [query, setQuery] = (0, import_react15.useState)(
    () => createMediaQueryString(features)
  );
  const [matches, setMatches] = (0, import_react15.useState)(() => {
    if (!isBrowser || disabled || initializeWithDefaultValue) {
      return defaultValue;
    }
    try {
      return window.matchMedia(query).matches;
    } catch (e) {
      console.error("Error initializing media query:", e);
      return defaultValue;
    }
  });
  const updateQuery = (0, import_react15.useCallback)(
    (newFeatures) => {
      const newQuery = createMediaQueryString(newFeatures);
      setQuery(newQuery);
    },
    [createMediaQueryString]
  );
  (0, import_react15.useEffect)(() => {
    if (!isBrowser || disabled) {
      return;
    }
    let mql;
    try {
      mql = window.matchMedia(query);
    } catch (e) {
      console.error("Error creating media query:", e);
      return;
    }
    setMatches(mql.matches);
    const handleChange = (e) => {
      setMatches(e.matches);
      if (onChange) {
        onChange(e.matches);
      }
    };
    if (mql.addEventListener) {
      mql.addEventListener("change", handleChange);
    } else {
      mql.addListener(handleChange);
    }
    return () => {
      if (mql.removeEventListener) {
        mql.removeEventListener("change", handleChange);
      } else {
        mql.removeListener(handleChange);
      }
    };
  }, [isBrowser, disabled, query, onChange]);
  return { matches, query, updateQuery };
}
function useMediaQueries(queries, options = {}) {
  const isBrowser = useIsBrowser();
  const result = Object.entries(queries).reduce((acc, [key, features]) => {
    const { matches } = useMediaQuery(features, options);
    acc[key] = matches;
    return acc;
  }, {});
  return result;
}
function useResponsive(options = {}) {
  return useMediaQueries(
    {
      isMobile: { maxWidth: "sm" },
      isTablet: { minWidth: "sm", maxWidth: "lg" },
      isDesktop: { minWidth: "lg", maxWidth: "xl" },
      isLargeDesktop: { minWidth: "xl" }
    },
    options
  );
}
function useDarkMode(options = {}) {
  const { matches } = useMediaQuery({ prefersColorScheme: "dark" }, options);
  return matches;
}
function usePrefersReducedMotion(options = {}) {
  const { matches } = useMediaQuery({ prefersReducedMotion: true }, options);
  return matches;
}
function useOrientation(options = {}) {
  const portrait = useMediaQuery({ orientation: "portrait" }, options);
  const landscape = useMediaQuery({ orientation: "landscape" }, options);
  return {
    isPortrait: portrait.matches,
    isLandscape: landscape.matches
  };
}

// src/hooks/useMouse.ts
var import_react16 = require("react");
var initPosition = () => ({
  x: 0,
  y: 0,
  clientX: 0,
  clientY: 0,
  pageX: 0,
  pageY: 0,
  screenX: 0,
  screenY: 0
});
var initButtons = () => ({
  left: false,
  right: false,
  middle: false
});
var initMovement = () => ({
  deltaX: 0,
  deltaY: 0,
  direction: 0,
  speed: 0,
  velocity: [0, 0]
});
function useMouse(options = {}) {
  const {
    target = null,
    disabled = false,
    eventTypes = [
      "mousemove",
      "mousedown",
      "mouseup",
      "mouseenter",
      "mouseleave"
    ],
    useCapture = false,
    preventDefault = false,
    stopPropagation = false,
    velocityDelay = 50,
    positionHistoryCount = 5,
    trackRelativePosition = true,
    onEnter,
    onLeave,
    onMove,
    onDown,
    onUp,
    onClick
  } = options;
  const isBrowser = useIsBrowser();
  const [position, setPosition] = (0, import_react16.useState)(initPosition);
  const [buttons, setButtons] = (0, import_react16.useState)(initButtons);
  const [isInside, setIsInside] = (0, import_react16.useState)(false);
  const [movement, setMovement] = (0, import_react16.useState)(initMovement);
  const [relativePosition, setRelativePosition] = (0, import_react16.useState)(null);
  const [targetElement, setTargetElement] = (0, import_react16.useState)(null);
  const lastEvent = (0, import_react16.useRef)(null);
  const velocityTimer = (0, import_react16.useRef)(null);
  const positionHistory = (0, import_react16.useRef)([]);
  const getTargetElement = (0, import_react16.useCallback)(() => {
    if (!isBrowser) return null;
    if (!target) {
      return document;
    }
    if ("current" in target) {
      return target.current;
    }
    return target;
  }, [isBrowser, target]);
  (0, import_react16.useEffect)(() => {
    if (!isBrowser || disabled) return;
    const element = getTargetElement();
    setTargetElement(element);
  }, [isBrowser, disabled, getTargetElement]);
  const calculateMovement = (0, import_react16.useCallback)(() => {
    if (positionHistory.current.length < 2) {
      return initMovement();
    }
    const current = positionHistory.current[positionHistory.current.length - 1];
    const previous = positionHistory.current[positionHistory.current.length - 2];
    if (!current || !previous) {
      return initMovement();
    }
    const deltaX = current.position.x - previous.position.x;
    const deltaY = current.position.y - previous.position.y;
    const timeDelta = current.timestamp - previous.timestamp;
    if (timeDelta === 0) {
      return { ...initMovement(), deltaX, deltaY };
    }
    const distance = Math.sqrt(deltaX * deltaX + deltaY * deltaY);
    const speed = distance / (timeDelta / 1e3);
    const velocityX = deltaX / (timeDelta / 1e3);
    const velocityY = deltaY / (timeDelta / 1e3);
    let direction = Math.atan2(deltaY, deltaX) * (180 / Math.PI);
    if (direction < 0) {
      direction += 360;
    }
    return {
      deltaX,
      deltaY,
      direction,
      speed,
      velocity: [velocityX, velocityY]
    };
  }, []);
  const calculateRelativePosition = (0, import_react16.useCallback)(
    (mouseEvent, element) => {
      if (!trackRelativePosition || !(element instanceof HTMLElement)) {
        return null;
      }
      const rect = element.getBoundingClientRect();
      const x = (mouseEvent.clientX - rect.left) / rect.width;
      const y = (mouseEvent.clientY - rect.top) / rect.height;
      return { x, y };
    },
    [trackRelativePosition]
  );
  const handleMouseEvent = (0, import_react16.useCallback)(
    (event) => {
      if (disabled) return;
      if (preventDefault) {
        event.preventDefault();
      }
      if (stopPropagation) {
        event.stopPropagation();
      }
      lastEvent.current = event;
      const newPosition = {
        x: event.clientX,
        y: event.clientY,
        clientX: event.clientX,
        clientY: event.clientY,
        pageX: event.pageX,
        pageY: event.pageY,
        screenX: event.screenX,
        screenY: event.screenY
      };
      setPosition(newPosition);
      const now = Date.now();
      positionHistory.current.push({ position: newPosition, timestamp: now });
      if (positionHistory.current.length > positionHistoryCount) {
        positionHistory.current.shift();
      }
      const newMovement = calculateMovement();
      setMovement(newMovement);
      if (velocityTimer.current) {
        clearTimeout(velocityTimer.current);
      }
      velocityTimer.current = setTimeout(() => {
        setMovement((prev) => ({
          ...prev,
          speed: 0,
          velocity: [0, 0]
        }));
      }, velocityDelay);
      if (event.type === "mousedown") {
        setButtons((prev) => ({
          left: event.button === 0 ? true : prev.left,
          right: event.button === 2 ? true : prev.right,
          middle: event.button === 1 ? true : prev.middle
        }));
        if (onDown) {
          onDown(
            {
              position: newPosition,
              buttons: {
                left: event.button === 0,
                right: event.button === 2,
                middle: event.button === 1
              },
              isInside: true,
              movement: newMovement,
              event
            },
            event.button
          );
        }
      } else if (event.type === "mouseup") {
        setButtons((prev) => ({
          left: event.button === 0 ? false : prev.left,
          right: event.button === 2 ? false : prev.right,
          middle: event.button === 1 ? false : prev.middle
        }));
        if (onUp) {
          onUp(
            {
              position: newPosition,
              buttons: {
                left: event.button === 0 ? false : buttons.left,
                right: event.button === 2 ? false : buttons.right,
                middle: event.button === 1 ? false : buttons.middle
              },
              isInside: true,
              movement: newMovement,
              event
            },
            event.button
          );
        }
      }
      if (event.type === "mouseenter") {
        setIsInside(true);
        if (onEnter) {
          onEnter({
            position: newPosition,
            buttons,
            isInside: true,
            movement: newMovement,
            event
          });
        }
      } else if (event.type === "mouseleave") {
        setIsInside(false);
        if (onLeave) {
          onLeave({
            position: newPosition,
            buttons,
            isInside: false,
            movement: newMovement,
            event
          });
        }
      }
      if (event.type === "mousemove") {
        if (onMove) {
          onMove({
            position: newPosition,
            buttons,
            isInside,
            movement: newMovement,
            event
          });
        }
        if (trackRelativePosition && event.target instanceof HTMLElement) {
          const element = targetElement instanceof HTMLElement ? targetElement : event.target;
          setRelativePosition(calculateRelativePosition(event, element));
        }
      }
      if (event.type === "click") {
        if (onClick) {
          onClick(
            {
              position: newPosition,
              buttons,
              isInside: true,
              movement: newMovement,
              event
            },
            event.button
          );
        }
      }
    },
    [
      disabled,
      preventDefault,
      stopPropagation,
      buttons,
      isInside,
      calculateMovement,
      velocityDelay,
      onDown,
      onUp,
      onEnter,
      onLeave,
      onMove,
      onClick,
      trackRelativePosition,
      targetElement,
      calculateRelativePosition,
      positionHistoryCount
    ]
  );
  (0, import_react16.useEffect)(() => {
    if (!isBrowser || disabled || !targetElement) {
      return;
    }
    eventTypes.forEach((eventType) => {
      targetElement.addEventListener(
        eventType,
        handleMouseEvent,
        useCapture
      );
    });
    return () => {
      eventTypes.forEach((eventType) => {
        targetElement.removeEventListener(
          eventType,
          handleMouseEvent,
          useCapture
        );
      });
      if (velocityTimer.current) {
        clearTimeout(velocityTimer.current);
      }
    };
  }, [
    isBrowser,
    disabled,
    targetElement,
    eventTypes,
    useCapture,
    handleMouseEvent
  ]);
  const reset = (0, import_react16.useCallback)(() => {
    setPosition(initPosition());
    setButtons(initButtons());
    setIsInside(false);
    setMovement(initMovement());
    setRelativePosition(null);
    positionHistory.current = [];
    lastEvent.current = null;
    if (velocityTimer.current) {
      clearTimeout(velocityTimer.current);
      velocityTimer.current = null;
    }
  }, []);
  return {
    position,
    buttons,
    isInside,
    movement,
    event: lastEvent.current,
    targetElement,
    relativePosition,
    reset
  };
}
function useMouseHover({
  target = null,
  delay = 0,
  ...restOptions
} = {}) {
  const [isHovered, setIsHovered] = (0, import_react16.useState)(false);
  const timerRef = (0, import_react16.useRef)(null);
  const mouse = useMouse({
    target,
    eventTypes: ["mouseenter", "mouseleave", "mousemove"],
    onEnter: (data) => {
      if (delay > 0) {
        if (timerRef.current) {
          clearTimeout(timerRef.current);
        }
        timerRef.current = setTimeout(() => {
          setIsHovered(true);
        }, delay);
      } else {
        setIsHovered(true);
      }
      if (restOptions.onEnter) {
        restOptions.onEnter(data);
      }
    },
    onLeave: (data) => {
      if (timerRef.current) {
        clearTimeout(timerRef.current);
      }
      setIsHovered(false);
      if (restOptions.onLeave) {
        restOptions.onLeave(data);
      }
    },
    ...restOptions
  });
  (0, import_react16.useEffect)(() => {
    return () => {
      if (timerRef.current) {
        clearTimeout(timerRef.current);
      }
    };
  }, []);
  return {
    ...mouse,
    isHovered
  };
}

// src/hooks/useNetwork.ts
var import_react17 = require("react");
var getInitialNetworkStatus = () => {
  const online = typeof navigator !== "undefined" ? navigator.onLine : true;
  return {
    online,
    firstTimeOffline: false,
    offlineCount: 0,
    lastChange: Date.now(),
    reconnecting: false,
    connection: {
      type: "unknown",
      effectiveType: "unknown",
      rtt: null,
      downlink: null,
      saveData: false
    }
  };
};
var getConnectionInfo = () => {
  const connection = typeof navigator !== "undefined" && navigator.connection;
  if (!connection) {
    return {
      type: "unknown",
      effectiveType: "unknown",
      rtt: null,
      downlink: null,
      saveData: false
    };
  }
  return {
    type: connection.type || "unknown",
    effectiveType: connection.effectiveType || "unknown",
    rtt: connection.rtt || null,
    downlink: connection.downlink || null,
    saveData: connection.saveData || false
  };
};
function useNetwork(options = {}) {
  const {
    pollingInterval = 0,
    autoReconnect = false,
    reconnectDelay = 1e3,
    maxReconnectAttempts = 10,
    exponentialBackoff = true,
    onReconnect,
    onOffline,
    onOnline,
    onChange
  } = options;
  const isBrowser = useIsBrowser();
  const [status, setStatus] = (0, import_react17.useState)(getInitialNetworkStatus);
  const reconnectAttempts = (0, import_react17.useRef)(0);
  const reconnectTimeoutRef = (0, import_react17.useRef)(null);
  const pollingIntervalRef = (0, import_react17.useRef)(null);
  const isFirstOfflineRef = (0, import_react17.useRef)(true);
  const offlineCountRef = (0, import_react17.useRef)(0);
  const checkStatus = (0, import_react17.useCallback)(async () => {
    if (!isBrowser) {
      return status;
    }
    const online = navigator.onLine;
    const connection = getConnectionInfo();
    const now = Date.now();
    let firstTimeOffline = status.firstTimeOffline;
    let offlineCount = offlineCountRef.current;
    if (!online && online !== status.online) {
      if (isFirstOfflineRef.current) {
        isFirstOfflineRef.current = false;
        firstTimeOffline = true;
      }
      offlineCountRef.current += 1;
      offlineCount = offlineCountRef.current;
      if (onOffline) {
        onOffline();
      }
    }
    if (online && online !== status.online) {
      if (onOnline) {
        onOnline();
      }
    }
    const newStatus = {
      online,
      firstTimeOffline,
      connection,
      lastChange: online !== status.online ? now : status.lastChange,
      offlineCount,
      reconnecting: status.reconnecting
    };
    if (online !== status.online || connection.type !== status.connection.type || connection.effectiveType !== status.connection.effectiveType) {
      setStatus(newStatus);
      if (onChange) {
        onChange(newStatus);
      }
    }
    return newStatus;
  }, [isBrowser, status, onOffline, onOnline, onChange]);
  const resetCounts = (0, import_react17.useCallback)(() => {
    isFirstOfflineRef.current = true;
    offlineCountRef.current = 0;
    setStatus((prev) => ({
      ...prev,
      firstTimeOffline: false,
      offlineCount: 0
    }));
  }, []);
  const clearTimers = (0, import_react17.useCallback)(() => {
    if (reconnectTimeoutRef.current) {
      clearTimeout(reconnectTimeoutRef.current);
      reconnectTimeoutRef.current = null;
    }
    if (pollingIntervalRef.current) {
      clearInterval(pollingIntervalRef.current);
      pollingIntervalRef.current = null;
    }
  }, []);
  const reconnect = (0, import_react17.useCallback)(async () => {
    if (!isBrowser || status.online) {
      return true;
    }
    setStatus((prev) => ({ ...prev, reconnecting: true }));
    try {
      await fetch("/favicon.ico", {
        mode: "no-cors",
        cache: "no-cache"
      });
      reconnectAttempts.current = 0;
      await checkStatus();
      setStatus((prev) => ({ ...prev, reconnecting: false }));
      if (onReconnect) {
        onReconnect();
      }
      return true;
    } catch (error) {
      reconnectAttempts.current += 1;
      if (reconnectAttempts.current >= maxReconnectAttempts) {
        setStatus((prev) => ({ ...prev, reconnecting: false }));
        return false;
      }
      const delay = exponentialBackoff ? reconnectDelay * Math.pow(2, reconnectAttempts.current - 1) : reconnectDelay;
      reconnectTimeoutRef.current = setTimeout(() => {
        reconnect();
      }, delay);
      return false;
    }
  }, [
    isBrowser,
    status.online,
    checkStatus,
    reconnectDelay,
    maxReconnectAttempts,
    exponentialBackoff,
    onReconnect
  ]);
  (0, import_react17.useEffect)(() => {
    if (!isBrowser) {
      return;
    }
    const handleOnline = () => {
      checkStatus();
    };
    const handleOffline = () => {
      checkStatus();
      if (autoReconnect) {
        reconnectTimeoutRef.current = setTimeout(() => {
          reconnect();
        }, reconnectDelay);
      }
    };
    checkStatus();
    if (pollingInterval > 0) {
      pollingIntervalRef.current = setInterval(() => {
        checkStatus();
      }, pollingInterval);
    }
    window.addEventListener("online", handleOnline);
    window.addEventListener("offline", handleOffline);
    if (navigator.connection) {
      navigator.connection.addEventListener("change", checkStatus);
    }
    return () => {
      window.removeEventListener("online", handleOnline);
      window.removeEventListener("offline", handleOffline);
      if (navigator.connection) {
        navigator.connection.removeEventListener("change", checkStatus);
      }
      clearTimers();
    };
  }, [
    isBrowser,
    autoReconnect,
    reconnectDelay,
    pollingInterval,
    checkStatus,
    reconnect,
    clearTimers
  ]);
  (0, import_react17.useEffect)(() => {
    return () => {
      clearTimers();
    };
  }, [clearTimers]);
  return {
    ...status,
    checkStatus,
    reconnect,
    resetCounts
  };
}
var fetchCache = /* @__PURE__ */ new Map();
function useFetch(initialUrl, options = {}) {
  const {
    disabled = false,
    autoFetch = true,
    cacheStrategy = "no-cache",
    cacheTime = 3e5,
    // 5 minutes
    cacheKey: customCacheKey,
    retry = false,
    retryCount: maxRetryCount = 3,
    retryDelay = 1e3,
    retryBackoff = true,
    abortOnUnmount = true,
    requestTransformers = [],
    responseTransformers = [],
    parser = (response2) => response2.json(),
    onSuccess,
    onError,
    onStart,
    onFinish,
    onAbort,
    onRetry,
    networkOptions = {
      retryOnReconnect: true,
      failFastWhenOffline: false
    },
    ...fetchOptions
  } = options;
  const isBrowser = useIsBrowser();
  const [data, setData] = (0, import_react17.useState)(null);
  const [error, setError] = (0, import_react17.useState)(null);
  const [loading, setLoading] = (0, import_react17.useState)(false);
  const [cached, setCached] = (0, import_react17.useState)(false);
  const [response, setResponse] = (0, import_react17.useState)(null);
  const [retryAttempts, setRetryAttempts] = (0, import_react17.useState)(0);
  const abortControllerRef = (0, import_react17.useRef)(null);
  const activeUrlRef = (0, import_react17.useRef)(initialUrl);
  const isMountedRef = (0, import_react17.useRef)(true);
  const retryTimeoutRef = (0, import_react17.useRef)(null);
  const pendingPromiseRef = (0, import_react17.useRef)(null);
  const network = useNetwork({
    onOnline: () => {
      if (networkOptions.retryOnReconnect && error) {
        executeFetch();
      }
    }
  });
  const getCacheKey = (0, import_react17.useCallback)(
    (url, opts) => {
      if (customCacheKey) {
        return customCacheKey;
      }
      const body = opts.body ? JSON.stringify(opts.body) : "";
      return `${opts.method || "GET"}-${url}-${body}`;
    },
    [customCacheKey]
  );
  const isCacheValid = (0, import_react17.useCallback)(
    (timestamp) => {
      return Date.now() - timestamp < cacheTime;
    },
    [cacheTime]
  );
  const clearCache = (0, import_react17.useCallback)(() => {
    const key = getCacheKey(activeUrlRef.current, fetchOptions);
    fetchCache.delete(key);
  }, [getCacheKey, fetchOptions]);
  const abort = (0, import_react17.useCallback)(() => {
    if (abortControllerRef.current) {
      abortControllerRef.current.abort();
      abortControllerRef.current = null;
      if (retryTimeoutRef.current) {
        clearTimeout(retryTimeoutRef.current);
        retryTimeoutRef.current = null;
      }
      if (onAbort) {
        onAbort();
      }
    }
  }, [onAbort]);
  const executeFetch = (0, import_react17.useCallback)(
    async (url = activeUrlRef.current, customOptions = {}) => {
      if (disabled || !isBrowser) {
        return null;
      }
      if (networkOptions.failFastWhenOffline && !network.online) {
        const offlineError = new Error("Network offline");
        setError(offlineError);
        if (onError) {
          onError(offlineError);
        }
        return null;
      }
      const mergedOptions = {
        ...options,
        ...customOptions
      };
      if (pendingPromiseRef.current && url === activeUrlRef.current) {
        return pendingPromiseRef.current;
      }
      abort();
      abortControllerRef.current = new AbortController();
      activeUrlRef.current = url;
      const cacheKey = getCacheKey(url, { ...fetchOptions, ...mergedOptions });
      const cachedItem = fetchCache.get(cacheKey);
      if (cacheStrategy !== "no-cache" && cachedItem && isCacheValid(cachedItem.timestamp)) {
        if (cacheStrategy === "cache-first") {
          setData(cachedItem.data);
          setResponse(cachedItem.response);
          setCached(true);
          setError(null);
          setLoading(false);
          if (onSuccess) {
            onSuccess(cachedItem.data, cachedItem.response);
          }
          return cachedItem.data;
        }
        if (cacheStrategy === "stale-while-revalidate") {
          setData(cachedItem.data);
          setResponse(cachedItem.response);
          setCached(true);
        }
      }
      setLoading(true);
      setCached(false);
      if (onStart) {
        onStart();
      }
      const fetchPromise = (async () => {
        try {
          let request = new Request(url, {
            ...fetchOptions,
            ...mergedOptions,
            signal: abortControllerRef.current.signal
          });
          for (const transformer of requestTransformers) {
            request = await transformer(request);
          }
          let fetchResponse = await fetch(request);
          for (const transformer of responseTransformers) {
            fetchResponse = await transformer(fetchResponse);
          }
          setResponse(fetchResponse);
          if (!fetchResponse.ok) {
            throw new Error(
              `HTTP error ${fetchResponse.status}: ${fetchResponse.statusText}`
            );
          }
          const responseData = await parser(fetchResponse.clone());
          if (isMountedRef.current) {
            setData(responseData);
            setError(null);
            setLoading(false);
            setRetryAttempts(0);
            if (cacheStrategy !== "no-cache") {
              fetchCache.set(cacheKey, {
                data: responseData,
                timestamp: Date.now(),
                response: fetchResponse.clone()
              });
            }
            if (onSuccess) {
              onSuccess(responseData, fetchResponse);
            }
          }
          if (onFinish) {
            onFinish();
          }
          pendingPromiseRef.current = null;
          return responseData;
        } catch (err) {
          if (err instanceof Error && err.name !== "AbortError" && isMountedRef.current) {
            const errorObj = err instanceof Error ? err : new Error(String(err));
            if (retry && retryAttempts < maxRetryCount) {
              const nextRetryCount = retryAttempts + 1;
              setRetryAttempts(nextRetryCount);
              if (onRetry) {
                onRetry(nextRetryCount, errorObj);
              }
              const delay = retryBackoff ? retryDelay * Math.pow(2, retryAttempts) : retryDelay;
              if (retryTimeoutRef.current) {
                clearTimeout(retryTimeoutRef.current);
              }
              retryTimeoutRef.current = setTimeout(() => {
                if (isMountedRef.current) {
                  executeFetch(url, mergedOptions);
                }
              }, delay);
              return null;
            }
            setError(errorObj);
            setLoading(false);
            if (onError) {
              onError(errorObj);
            }
          }
          if (onFinish) {
            onFinish();
          }
          pendingPromiseRef.current = null;
          return null;
        }
      })();
      pendingPromiseRef.current = fetchPromise;
      return fetchPromise;
    },
    [
      disabled,
      isBrowser,
      networkOptions.failFastWhenOffline,
      network.online,
      options,
      abort,
      getCacheKey,
      fetchOptions,
      cacheStrategy,
      isCacheValid,
      requestTransformers,
      responseTransformers,
      parser,
      onSuccess,
      onError,
      onStart,
      onFinish,
      onRetry,
      retry,
      retryAttempts,
      maxRetryCount,
      retryBackoff,
      retryDelay
    ]
  );
  (0, import_react17.useEffect)(() => {
    isMountedRef.current = true;
    if (autoFetch && !disabled) {
      executeFetch();
    }
    return () => {
      isMountedRef.current = false;
      if (abortOnUnmount) {
        abort();
      }
      if (retryTimeoutRef.current) {
        clearTimeout(retryTimeoutRef.current);
      }
    };
  }, [autoFetch, disabled, executeFetch, abort, abortOnUnmount]);
  return {
    data,
    error,
    loading,
    cached,
    response,
    fetch: executeFetch,
    abort,
    retryCount: retryAttempts,
    clearCache
  };
}

// src/hooks/usePreferredLanguage.ts
var import_react19 = require("react");

// src/hooks/useLocalStorage.ts
var import_react18 = require("react");
function useLocalStorage(key, options = {}) {
  const {
    defaultValue,
    serialize = JSON.stringify,
    deserialize = JSON.parse,
    syncAcrossTabs = true,
    listenToStorageChanges = true,
    onError,
    storageType = "localStorage",
    disabled = false,
    processBeforeStorage = (value) => value,
    processAfterRetrieval = (value) => value
  } = options;
  const isBrowser = useIsBrowser();
  const [storedValue, setStoredValue] = (0, import_react18.useState)(() => {
    if (!isBrowser || disabled) {
      return defaultValue;
    }
    try {
      const storage = window[storageType];
      const item = storage.getItem(key);
      if (item === null) {
        return defaultValue;
      }
      const parsedValue = deserialize(item);
      return processAfterRetrieval(parsedValue);
    } catch (error2) {
      const err = error2 instanceof Error ? error2 : new Error(String(error2));
      if (onError) {
        onError(err, "get");
      } else {
        console.error(`Error reading localStorage key "${key}":`, err);
      }
      return defaultValue;
    }
  });
  const [hasError, setHasError] = (0, import_react18.useState)(false);
  const [error, setError] = (0, import_react18.useState)(null);
  const [exists, setExists] = (0, import_react18.useState)(false);
  const latestValueRef = (0, import_react18.useRef)(storedValue);
  const checkExists = (0, import_react18.useCallback)(() => {
    if (!isBrowser || disabled) {
      setExists(false);
      return false;
    }
    try {
      const storage = window[storageType];
      const exists2 = storage.getItem(key) !== null;
      setExists(exists2);
      return exists2;
    } catch (error2) {
      setExists(false);
      return false;
    }
  }, [isBrowser, key, storageType, disabled]);
  (0, import_react18.useEffect)(() => {
    latestValueRef.current = storedValue;
  }, [storedValue]);
  (0, import_react18.useEffect)(() => {
    if (!isBrowser || !syncAcrossTabs || !listenToStorageChanges || disabled) {
      return;
    }
    const handleStorageChange = (e) => {
      if (e.key !== key || e.storageArea !== window[storageType]) {
        return;
      }
      try {
        if (e.newValue === null) {
          setStoredValue(defaultValue);
          setExists(false);
          return;
        }
        const newValue = deserialize(e.newValue);
        const processedValue = processAfterRetrieval(newValue);
        if (JSON.stringify(processedValue) !== JSON.stringify(latestValueRef.current)) {
          setStoredValue(processedValue);
          setExists(true);
        }
      } catch (error2) {
        const err = error2 instanceof Error ? error2 : new Error(String(error2));
        setHasError(true);
        setError(err);
        if (onError) {
          onError(err, "get");
        } else {
          console.error(`Error syncing localStorage key "${key}":`, err);
        }
      }
    };
    window.addEventListener("storage", handleStorageChange);
    return () => {
      window.removeEventListener("storage", handleStorageChange);
    };
  }, [
    isBrowser,
    key,
    syncAcrossTabs,
    listenToStorageChanges,
    deserialize,
    defaultValue,
    onError,
    storageType,
    disabled,
    processAfterRetrieval
  ]);
  (0, import_react18.useEffect)(() => {
    checkExists();
  }, [checkExists]);
  const setValue = (0, import_react18.useCallback)(
    (valueOrFn) => {
      if (!isBrowser || disabled) {
        const newValue = typeof valueOrFn === "function" ? valueOrFn(latestValueRef.current) : valueOrFn;
        setStoredValue(newValue);
        return;
      }
      try {
        const valueToStore = typeof valueOrFn === "function" ? valueOrFn(latestValueRef.current) : valueOrFn;
        const processedValue = processBeforeStorage(valueToStore);
        setStoredValue(valueToStore);
        setHasError(false);
        setError(null);
        setExists(true);
        const storage = window[storageType];
        storage.setItem(key, serialize(processedValue));
      } catch (error2) {
        const err = error2 instanceof Error ? error2 : new Error(String(error2));
        setHasError(true);
        setError(err);
        if (onError) {
          onError(err, "set");
        } else {
          console.error(`Error setting localStorage key "${key}":`, err);
        }
      }
    },
    [
      isBrowser,
      key,
      serialize,
      onError,
      storageType,
      disabled,
      processBeforeStorage
    ]
  );
  const removeValue = (0, import_react18.useCallback)(() => {
    if (!isBrowser || disabled) {
      setStoredValue(defaultValue);
      return;
    }
    try {
      const storage = window[storageType];
      storage.removeItem(key);
      setStoredValue(defaultValue);
      setHasError(false);
      setError(null);
      setExists(false);
    } catch (error2) {
      const err = error2 instanceof Error ? error2 : new Error(String(error2));
      setHasError(true);
      setError(err);
      if (onError) {
        onError(err, "remove");
      } else {
        console.error(`Error removing localStorage key "${key}":`, err);
      }
    }
  }, [isBrowser, key, defaultValue, onError, storageType, disabled]);
  const resetToDefault = (0, import_react18.useCallback)(() => {
    if (defaultValue === void 0) {
      removeValue();
    } else {
      setValue(defaultValue);
    }
  }, [defaultValue, removeValue, setValue]);
  return {
    value: storedValue,
    setValue,
    removeValue,
    hasError,
    error,
    resetToDefault,
    key,
    exists
  };
}

// src/hooks/usePreferredLanguage.ts
function usePreferredLanguage(options = {}) {
  const {
    defaultLanguage = "en",
    persistPreference = true,
    storageKey = "preferred_language",
    supportedLanguages,
    useFullLocale = false,
    onChange
  } = options;
  const isBrowser = useIsBrowser();
  const { value: storedLanguage, setValue: setStoredLanguage } = useLocalStorage(persistPreference ? storageKey : "", {
    defaultValue: "",
    disabled: !persistPreference
  });
  const [language, setLanguageState] = (0, import_react19.useState)(defaultLanguage);
  const [isDetected, setIsDetected] = (0, import_react19.useState)(false);
  const [isPersisted, setIsPersisted] = (0, import_react19.useState)(false);
  const [browserLanguages, setBrowserLanguages] = (0, import_react19.useState)([]);
  const isSupported = (0, import_react19.useCallback)(
    (lang) => {
      if (!supportedLanguages) return true;
      return supportedLanguages.includes(lang);
    },
    [supportedLanguages]
  );
  const normalizeLanguage = (0, import_react19.useCallback)(
    (locale) => {
      if (useFullLocale) return locale;
      return locale.split("-")[0].toLowerCase();
    },
    [useFullLocale]
  );
  const detectBrowserLanguage = (0, import_react19.useCallback)(() => {
    if (!isBrowser) return defaultLanguage;
    const browserLangs = navigator.languages || [navigator.language];
    const normalizedLangs = browserLangs.map(normalizeLanguage);
    setBrowserLanguages(normalizedLangs);
    if (supportedLanguages) {
      const supported = normalizedLangs.find(
        (lang) => supportedLanguages.includes(lang)
      );
      if (supported) return supported;
    }
    return normalizedLangs[0] || defaultLanguage;
  }, [isBrowser, defaultLanguage, normalizeLanguage, supportedLanguages]);
  const setLanguage = (0, import_react19.useCallback)(
    (newLanguage) => {
      const normalized = normalizeLanguage(newLanguage);
      if (supportedLanguages && !isSupported(normalized)) {
        console.warn(
          `Language ${normalized} is not in the supported languages list.`
        );
        return;
      }
      setLanguageState(normalized);
      setIsDetected(false);
      if (persistPreference) {
        setStoredLanguage(normalized);
      }
      if (onChange) {
        onChange(normalized);
      }
    },
    [
      normalizeLanguage,
      supportedLanguages,
      isSupported,
      persistPreference,
      setStoredLanguage,
      onChange
    ]
  );
  const resetToSystemDefault = (0, import_react19.useCallback)(() => {
    const browserLang = detectBrowserLanguage();
    setLanguageState(browserLang);
    setIsDetected(true);
    if (persistPreference) {
      setStoredLanguage("");
    }
    if (onChange) {
      onChange(browserLang);
    }
  }, [detectBrowserLanguage, persistPreference, setStoredLanguage, onChange]);
  (0, import_react19.useEffect)(() => {
    if (!isBrowser) return;
    if (persistPreference && storedLanguage) {
      setLanguageState(storedLanguage);
      setIsPersisted(true);
      setIsDetected(false);
    } else {
      const detected = detectBrowserLanguage();
      setLanguageState(detected);
      setIsDetected(true);
      setIsPersisted(false);
    }
  }, [isBrowser, persistPreference, storedLanguage, detectBrowserLanguage]);
  (0, import_react19.useEffect)(() => {
    if (!isBrowser) return;
    const handleLanguageChange = () => {
      if (isDetected) {
        const newDetected = detectBrowserLanguage();
        setLanguageState(newDetected);
        if (onChange) {
          onChange(newDetected);
        }
      }
    };
    return () => {
    };
  }, [isBrowser, isDetected, detectBrowserLanguage, onChange]);
  return {
    language,
    isDetected,
    isPersisted,
    setLanguage,
    resetToSystemDefault,
    browserLanguages,
    isSupported
  };
}

// src/hooks/useCookie.ts
var import_react20 = require("react");
function formatCookieAttributes(attributes) {
  const pieces = [];
  if (attributes.expires) {
    const expires = attributes.expires;
    if (typeof expires === "number") {
      const expiryDate = new Date(Date.now() + expires * 1e3);
      pieces.push(`expires=${expiryDate.toUTCString()}`);
    } else if (typeof expires === "string") {
      pieces.push(`expires=${expires}`);
    } else {
      pieces.push(`expires=${expires.toUTCString()}`);
    }
  }
  if (attributes.maxAge !== void 0) {
    pieces.push(`max-age=${attributes.maxAge}`);
  }
  if (attributes.domain) {
    pieces.push(`domain=${attributes.domain}`);
  }
  if (attributes.path) {
    pieces.push(`path=${attributes.path}`);
  } else {
    pieces.push("path=/");
  }
  if (attributes.secure) {
    pieces.push("secure");
  }
  if (attributes.httpOnly) {
    pieces.push("HttpOnly");
  }
  if (attributes.sameSite) {
    pieces.push(`SameSite=${attributes.sameSite}`);
  } else {
    pieces.push("SameSite=Lax");
  }
  return pieces.join("; ");
}
function parseCookies() {
  if (typeof document === "undefined") {
    return {};
  }
  return document.cookie.split(";").reduce((cookies, cookieString) => {
    const [name, value] = cookieString.trim().split("=").map(decodeURIComponent);
    cookies[name] = value;
    return cookies;
  }, {});
}
function useCookie(key, options = {}) {
  const {
    defaultValue,
    attributes: defaultAttributes = {},
    serialize = JSON.stringify,
    deserialize = JSON.parse,
    disabled = false,
    autoEncode = true,
    onError,
    onChange
  } = options;
  const isBrowser = useIsBrowser();
  const [value, setValue] = (0, import_react20.useState)(() => {
    if (!isBrowser || disabled) {
      return defaultValue;
    }
    try {
      return getCookieValue();
    } catch (error2) {
      const err = error2 instanceof Error ? error2 : new Error(String(error2));
      if (onError) {
        onError(err, "get");
      } else {
        console.error(`Error getting cookie "${key}":`, err);
      }
      return defaultValue;
    }
  });
  const [error, setError] = (0, import_react20.useState)(null);
  const [hasValue, setHasValue] = (0, import_react20.useState)(false);
  const getCookieValue = (0, import_react20.useCallback)(() => {
    if (!isBrowser) {
      return defaultValue;
    }
    const cookies = parseCookies();
    const cookieValue = cookies[key];
    if (cookieValue === void 0) {
      setHasValue(false);
      return defaultValue;
    }
    setHasValue(true);
    try {
      return cookieValue ? deserialize(cookieValue) : defaultValue;
    } catch {
      return cookieValue;
    }
  }, [isBrowser, key, defaultValue, deserialize]);
  const updateValue = (0, import_react20.useCallback)(() => {
    const newValue = getCookieValue();
    setValue(newValue);
    return newValue;
  }, [getCookieValue]);
  const setCookie = (0, import_react20.useCallback)(
    (newValue, customAttributes = {}) => {
      try {
        if (disabled) {
          setValue(newValue);
          return;
        }
        if (!isBrowser) {
          return;
        }
        const attributes = { ...defaultAttributes, ...customAttributes };
        const prevValue = value;
        let stringValue;
        try {
          stringValue = typeof newValue === "string" ? newValue : serialize(newValue);
        } catch (e) {
          const err = e instanceof Error ? e : new Error(String(e));
          if (onError) {
            onError(err, "set");
          } else {
            console.error(`Error serializing cookie value for "${key}":`, err);
          }
          stringValue = String(newValue);
        }
        const cookieValue = autoEncode ? encodeURIComponent(stringValue) : stringValue;
        document.cookie = `${encodeURIComponent(
          key
        )}=${cookieValue}; ${formatCookieAttributes(attributes)}`;
        setValue(newValue);
        setHasValue(true);
        setError(null);
        if (onChange && newValue !== prevValue) {
          onChange(newValue, prevValue);
        }
      } catch (error2) {
        const err = error2 instanceof Error ? error2 : new Error(String(error2));
        setError(err);
        if (onError) {
          onError(err, "set");
        } else {
          console.error(`Error setting cookie "${key}":`, err);
        }
      }
    },
    [
      disabled,
      isBrowser,
      key,
      defaultAttributes,
      value,
      serialize,
      autoEncode,
      onChange,
      onError
    ]
  );
  const removeCookie = (0, import_react20.useCallback)(
    (customAttributes = {}) => {
      try {
        if (disabled) {
          setValue(defaultValue);
          setHasValue(false);
          return;
        }
        if (!isBrowser) {
          return;
        }
        const prevValue = value;
        const attributes = {
          ...defaultAttributes,
          ...customAttributes,
          expires: /* @__PURE__ */ new Date(0),
          // Set to epoch to expire immediately
          maxAge: 0
        };
        document.cookie = `${encodeURIComponent(
          key
        )}=; ${formatCookieAttributes(attributes)}`;
        setValue(defaultValue);
        setHasValue(false);
        setError(null);
        if (onChange && prevValue !== defaultValue) {
          onChange(defaultValue, prevValue);
        }
      } catch (error2) {
        const err = error2 instanceof Error ? error2 : new Error(String(error2));
        setError(err);
        if (onError) {
          onError(err, "remove");
        } else {
          console.error(`Error removing cookie "${key}":`, err);
        }
      }
    },
    [
      disabled,
      isBrowser,
      key,
      defaultAttributes,
      defaultValue,
      value,
      onChange,
      onError
    ]
  );
  const getAllCookies = (0, import_react20.useCallback)(() => {
    if (!isBrowser) {
      return {};
    }
    return parseCookies();
  }, [isBrowser]);
  (0, import_react20.useEffect)(() => {
    if (isBrowser && !disabled) {
      updateValue();
    }
  }, [isBrowser, key, disabled, updateValue]);
  (0, import_react20.useEffect)(() => {
    if (!isBrowser || disabled) {
      return;
    }
    const handleStorageChange = () => {
      updateValue();
    };
    window.addEventListener("storage", handleStorageChange);
    return () => {
      window.removeEventListener("storage", handleStorageChange);
    };
  }, [isBrowser, disabled, updateValue]);
  return {
    value,
    setCookie,
    removeCookie,
    hasValue,
    error,
    updateValue,
    getAllCookies
  };
}
function useCookies(options = {}) {
  const isBrowser = useIsBrowser();
  const [cookies, setCookies] = (0, import_react20.useState)({});
  const getAllCookies = (0, import_react20.useCallback)(() => {
    if (!isBrowser) {
      return {};
    }
    const all = parseCookies();
    setCookies(all);
    return all;
  }, [isBrowser]);
  const getCookie = (0, import_react20.useCallback)(
    (name, defaultValue, deserialize = JSON.parse) => {
      if (!isBrowser) {
        return defaultValue;
      }
      const cookies2 = parseCookies();
      const value = cookies2[name];
      if (value === void 0) {
        return defaultValue;
      }
      try {
        return deserialize(value);
      } catch {
        return value;
      }
    },
    [isBrowser]
  );
  const setCookie = (0, import_react20.useCallback)(
    (name, value, attributes = {}, serialize = JSON.stringify) => {
      if (!isBrowser) {
        return;
      }
      const stringValue = typeof value === "string" ? value : serialize(value);
      const cookieValue = encodeURIComponent(stringValue);
      document.cookie = `${encodeURIComponent(
        name
      )}=${cookieValue}; ${formatCookieAttributes(attributes)}`;
      getAllCookies();
    },
    [isBrowser, getAllCookies]
  );
  const removeCookie = (0, import_react20.useCallback)(
    (name, attributes = {}) => {
      if (!isBrowser) {
        return;
      }
      const removeAttrs = {
        ...attributes,
        expires: /* @__PURE__ */ new Date(0),
        maxAge: 0
      };
      document.cookie = `${encodeURIComponent(name)}=; ${formatCookieAttributes(
        removeAttrs
      )}`;
      getAllCookies();
    },
    [isBrowser, getAllCookies]
  );
  const clearAllCookies = (0, import_react20.useCallback)(() => {
    if (!isBrowser) {
      return;
    }
    const allCookies = parseCookies();
    Object.keys(allCookies).forEach((name) => {
      removeCookie(name);
    });
    getAllCookies();
  }, [isBrowser, removeCookie, getAllCookies]);
  (0, import_react20.useEffect)(() => {
    if (isBrowser) {
      getAllCookies();
    }
  }, [isBrowser, getAllCookies]);
  (0, import_react20.useEffect)(() => {
    if (!isBrowser) {
      return;
    }
    const handleStorageChange = () => {
      getAllCookies();
    };
    window.addEventListener("storage", handleStorageChange);
    return () => {
      window.removeEventListener("storage", handleStorageChange);
    };
  }, [isBrowser, getAllCookies]);
  return {
    cookies,
    getCookie,
    setCookie,
    removeCookie,
    clearAllCookies,
    getAllCookies
  };
}

// src/hooks/useSessionStorage.ts
var import_react21 = require("react");
function useSessionStorage(key, options = {}) {
  const {
    defaultValue,
    serialize = JSON.stringify,
    deserialize = JSON.parse,
    onError,
    disabled = false,
    processBeforeStorage = (value) => value,
    processAfterRetrieval = (value) => value,
    onChange
  } = options;
  const isBrowser = useIsBrowser();
  const [storedValue, setStoredValue] = (0, import_react21.useState)(() => {
    if (!isBrowser || disabled) {
      return defaultValue;
    }
    try {
      const storage = window.sessionStorage;
      const item = storage.getItem(key);
      if (item === null) {
        return defaultValue;
      }
      const parsedValue = deserialize(item);
      return processAfterRetrieval(parsedValue);
    } catch (error2) {
      const err = error2 instanceof Error ? error2 : new Error(String(error2));
      if (onError) {
        onError(err, "get");
      } else {
        console.error(`Error reading sessionStorage key "${key}":`, err);
      }
      return defaultValue;
    }
  });
  const [hasError, setHasError] = (0, import_react21.useState)(false);
  const [error, setError] = (0, import_react21.useState)(null);
  const [exists, setExists] = (0, import_react21.useState)(false);
  const oldValueRef = (0, import_react21.useRef)(void 0);
  const latestValueRef = (0, import_react21.useRef)(storedValue);
  (0, import_react21.useEffect)(() => {
    latestValueRef.current = storedValue;
    oldValueRef.current = storedValue;
  }, [storedValue]);
  const checkExists = (0, import_react21.useCallback)(() => {
    if (!isBrowser || disabled) {
      setExists(false);
      return false;
    }
    try {
      const storage = window.sessionStorage;
      const exists2 = storage.getItem(key) !== null;
      setExists(exists2);
      return exists2;
    } catch (error2) {
      setExists(false);
      return false;
    }
  }, [isBrowser, key, disabled]);
  const setValue = (0, import_react21.useCallback)(
    (valueOrFn) => {
      if (!isBrowser || disabled) {
        const newValue = typeof valueOrFn === "function" ? valueOrFn(latestValueRef.current) : valueOrFn;
        setStoredValue(newValue);
        return;
      }
      try {
        const valueToStore = typeof valueOrFn === "function" ? valueOrFn(latestValueRef.current) : valueOrFn;
        const processedValue = processBeforeStorage(valueToStore);
        setStoredValue(valueToStore);
        setHasError(false);
        setError(null);
        setExists(true);
        const storage = window.sessionStorage;
        storage.setItem(key, serialize(processedValue));
        if (onChange && oldValueRef.current !== valueToStore) {
          onChange(valueToStore, oldValueRef.current);
        }
      } catch (error2) {
        const err = error2 instanceof Error ? error2 : new Error(String(error2));
        setHasError(true);
        setError(err);
        if (onError) {
          onError(err, "set");
        } else {
          console.error(`Error setting sessionStorage key "${key}":`, err);
        }
      }
    },
    [
      isBrowser,
      key,
      serialize,
      onError,
      disabled,
      processBeforeStorage,
      onChange
    ]
  );
  const removeValue = (0, import_react21.useCallback)(() => {
    if (!isBrowser || disabled) {
      setStoredValue(defaultValue);
      return;
    }
    try {
      const oldValue = latestValueRef.current;
      const storage = window.sessionStorage;
      storage.removeItem(key);
      setStoredValue(defaultValue);
      setHasError(false);
      setError(null);
      setExists(false);
      if (onChange && oldValue !== defaultValue) {
        onChange(defaultValue, oldValue);
      }
    } catch (error2) {
      const err = error2 instanceof Error ? error2 : new Error(String(error2));
      setHasError(true);
      setError(err);
      if (onError) {
        onError(err, "remove");
      } else {
        console.error(`Error removing sessionStorage key "${key}":`, err);
      }
    }
  }, [isBrowser, key, defaultValue, onError, disabled, onChange]);
  const resetToDefault = (0, import_react21.useCallback)(() => {
    if (defaultValue === void 0) {
      removeValue();
    } else {
      setValue(defaultValue);
    }
  }, [defaultValue, removeValue, setValue]);
  (0, import_react21.useEffect)(() => {
    checkExists();
  }, [checkExists]);
  (0, import_react21.useEffect)(() => {
    if (!isBrowser || disabled) {
      return;
    }
    const handleStorageChange = (e) => {
      if (e.storageArea !== window.sessionStorage || e.key !== key) {
        return;
      }
      checkExists();
      if (e.newValue === null) {
        setStoredValue(defaultValue);
        return;
      }
      try {
        const newValue = deserialize(e.newValue);
        const processedValue = processAfterRetrieval(newValue);
        if (JSON.stringify(processedValue) !== JSON.stringify(latestValueRef.current)) {
          setStoredValue(processedValue);
          if (onChange) {
            onChange(processedValue, latestValueRef.current);
          }
        }
      } catch (err) {
      }
    };
    window.addEventListener("storage", handleStorageChange);
    return () => {
      window.removeEventListener("storage", handleStorageChange);
    };
  }, [
    isBrowser,
    key,
    disabled,
    deserialize,
    defaultValue,
    processAfterRetrieval,
    checkExists,
    onChange
  ]);
  return {
    value: storedValue,
    setValue,
    removeValue,
    hasError,
    error,
    resetToDefault,
    key,
    exists,
    checkExists
  };
}
function useSessionStorageObject(namespace, options = {}) {
  const {
    serialize = JSON.stringify,
    deserialize = JSON.parse,
    onError,
    disabled = false
  } = options;
  const isBrowser = useIsBrowser();
  const [hasError, setHasError] = (0, import_react21.useState)(false);
  const [error, setError] = (0, import_react21.useState)(null);
  const [keys, setKeys] = (0, import_react21.useState)([]);
  const getNamespacedKey = (0, import_react21.useCallback)(
    (key) => `${namespace}:${key}`,
    [namespace]
  );
  const isNamespacedKey = (0, import_react21.useCallback)(
    (fullKey) => fullKey.startsWith(`${namespace}:`),
    [namespace]
  );
  const extractKey = (0, import_react21.useCallback)(
    (namespacedKey) => {
      if (isNamespacedKey(namespacedKey)) {
        return namespacedKey.slice(namespace.length + 1);
      }
      return namespacedKey;
    },
    [namespace, isNamespacedKey]
  );
  const refreshKeys = (0, import_react21.useCallback)(() => {
    if (!isBrowser || disabled) {
      setKeys([]);
      return [];
    }
    try {
      const storage = window.sessionStorage;
      const allKeys = Object.keys(storage);
      const namespaceKeys = allKeys.filter(isNamespacedKey).map(extractKey);
      setKeys(namespaceKeys);
      return namespaceKeys;
    } catch (error2) {
      const err = error2 instanceof Error ? error2 : new Error(String(error2));
      setHasError(true);
      setError(err);
      if (onError) {
        onError(err, "get");
      } else {
        console.error(`Error listing keys for namespace "${namespace}":`, err);
      }
      return [];
    }
  }, [isBrowser, disabled, isNamespacedKey, extractKey, namespace, onError]);
  const getItem = (0, import_react21.useCallback)(
    (key, defaultValue) => {
      if (!isBrowser || disabled) {
        return defaultValue;
      }
      try {
        const storage = window.sessionStorage;
        const namespacedKey = getNamespacedKey(key);
        const item = storage.getItem(namespacedKey);
        if (item === null) {
          return defaultValue;
        }
        const value = deserialize(item);
        setHasError(false);
        setError(null);
        return value;
      } catch (error2) {
        const err = error2 instanceof Error ? error2 : new Error(String(error2));
        setHasError(true);
        setError(err);
        if (onError) {
          onError(err, "get");
        } else {
          console.error(
            `Error getting item "${key}" from namespace "${namespace}":`,
            err
          );
        }
        return defaultValue;
      }
    },
    [isBrowser, disabled, getNamespacedKey, deserialize, namespace, onError]
  );
  const setItem = (0, import_react21.useCallback)(
    (key, value) => {
      if (!isBrowser || disabled) {
        return;
      }
      try {
        const storage = window.sessionStorage;
        const namespacedKey = getNamespacedKey(key);
        const serialized = serialize(value);
        storage.setItem(namespacedKey, serialized);
        setHasError(false);
        setError(null);
        if (!keys.includes(key)) {
          refreshKeys();
        }
      } catch (error2) {
        const err = error2 instanceof Error ? error2 : new Error(String(error2));
        setHasError(true);
        setError(err);
        if (onError) {
          onError(err, "set");
        } else {
          console.error(
            `Error setting item "${key}" in namespace "${namespace}":`,
            err
          );
        }
      }
    },
    [
      isBrowser,
      disabled,
      getNamespacedKey,
      serialize,
      namespace,
      keys,
      refreshKeys,
      onError
    ]
  );
  const removeItem = (0, import_react21.useCallback)(
    (key) => {
      if (!isBrowser || disabled) {
        return;
      }
      try {
        const storage = window.sessionStorage;
        const namespacedKey = getNamespacedKey(key);
        storage.removeItem(namespacedKey);
        setHasError(false);
        setError(null);
        refreshKeys();
      } catch (error2) {
        const err = error2 instanceof Error ? error2 : new Error(String(error2));
        setHasError(true);
        setError(err);
        if (onError) {
          onError(err, "remove");
        } else {
          console.error(
            `Error removing item "${key}" from namespace "${namespace}":`,
            err
          );
        }
      }
    },
    [isBrowser, disabled, getNamespacedKey, namespace, refreshKeys, onError]
  );
  const clear = (0, import_react21.useCallback)(() => {
    if (!isBrowser || disabled) {
      return;
    }
    try {
      const storage = window.sessionStorage;
      const keysToRemove = [...keys];
      keysToRemove.forEach((key) => {
        const namespacedKey = getNamespacedKey(key);
        storage.removeItem(namespacedKey);
      });
      setHasError(false);
      setError(null);
      setKeys([]);
    } catch (error2) {
      const err = error2 instanceof Error ? error2 : new Error(String(error2));
      setHasError(true);
      setError(err);
      if (onError) {
        onError(err, "remove");
      } else {
        console.error(`Error clearing namespace "${namespace}":`, err);
      }
    }
  }, [isBrowser, disabled, keys, getNamespacedKey, namespace, onError]);
  const getAll = (0, import_react21.useCallback)(() => {
    if (!isBrowser || disabled) {
      return {};
    }
    try {
      const result = {};
      keys.forEach((key) => {
        result[key] = getItem(key);
      });
      return result;
    } catch (error2) {
      const err = error2 instanceof Error ? error2 : new Error(String(error2));
      setHasError(true);
      setError(err);
      if (onError) {
        onError(err, "get");
      } else {
        console.error(
          `Error getting all items from namespace "${namespace}":`,
          err
        );
      }
      return {};
    }
  }, [isBrowser, disabled, keys, getItem, namespace, onError]);
  const hasItem = (0, import_react21.useCallback)(
    (key) => {
      if (!isBrowser || disabled) {
        return false;
      }
      try {
        const storage = window.sessionStorage;
        const namespacedKey = getNamespacedKey(key);
        return storage.getItem(namespacedKey) !== null;
      } catch (error2) {
        return false;
      }
    },
    [isBrowser, disabled, getNamespacedKey]
  );
  (0, import_react21.useEffect)(() => {
    if (isBrowser && !disabled) {
      refreshKeys();
    }
  }, [isBrowser, disabled, refreshKeys, namespace]);
  return {
    getItem,
    setItem,
    removeItem,
    clear,
    getAll,
    hasItem,
    hasError,
    error,
    keys,
    namespace,
    refreshKeys
  };
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  breakpoints,
  useBattery,
  useClickOutside,
  useClipboard,
  useCookie,
  useCookies,
  useDarkMode,
  useDebounce,
  useFetch,
  useGeolocation,
  useHasRendered,
  useHover,
  useIdle,
  useIntersectionObserver,
  useIsBrowser,
  useIsServer,
  useLocalStorage,
  useLockBodyScroll,
  useLongPress,
  useMediaQueries,
  useMediaQuery,
  useMouse,
  useMouseHover,
  useNetwork,
  useOrientation,
  usePreferredLanguage,
  usePrefersReducedMotion,
  useResponsive,
  useSessionStorage,
  useSessionStorageObject
});
